
/************************************************************************
 *
 * SR/Z3950 application software version 1.0, August 1993.
 *
 * (C) Software Kinetics Ltd.
 *
 * Software Kinetics Ltd. has granted a licence of this software to the
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve, reproduce
 * and sell the software.
 *
 * The software is provided to the user "as is" without warranty of any
 * kind. Neither Software Kinetics Ltd. nor the National Library of Canada
 * warrants, guarantees or makes any representations regarding the use,
 * or the results of use of the software in terms of accuracy, reliability,
 * or otherwise. The entire risk as to results and performance of the
 * software is assumed by the user. Neither Software Kinetics Ltd. nor the
 * National Library of Canada shall be liable for any direct, indirect,
 * consequential or incidental damages arising out of the use of the
 * software.
 *
 ************************************************************************/

/****************************************************************************
 * HEADER ir_ali.h
 *
 * PURPOSE:
 *	This header file is the general Application Layer Interface file. 
 *
 * SCOPE:
 *	All Origin Kernel CSCs that use ALI data types must include this
 *	file. All Origin Process CSCs that invoke ALI primitives must include
 *	this file.
 *
 * NOTES:
 * 	All data pointers specified in the interface structures are
 *	memory allocated data structures. It is the responsibility of
 *	the calling application to free this memory when it is done
 *	with it. 
 *
 *
 * $Log:
 * Revision 1.1  1993/09/16  09:03:27  irorigin
 * Baseline for Release 1.0.
 *
 * 
 ****************************************************************************/

#ifndef IR_ALI_H

#define IR_ALI_H

#include <ir.h>
#include <apdu.h>

/****************************************************************************
 * Send Request and Response Data types:
 ****************************************************************************/

typedef SHORT IRK_REQ_SERVICE_TYPE;

#define IRK_INIT_REQ_TYPE		1
#define IRK_SEARCH_REQ_TYPE		2
#define IRK_PRESENT_REQ_TYPE		3
#define IRK_DELETE_REQ_TYPE		4
#define IRK_TRIG_REQ_TYPE		5
#define IRK_RES_RPT_REQ_TYPE		6
#define IRK_RELEASE_REQ_TYPE		7
#define IRK_ABORT_REQ_TYPE		8
#define IRK_ACCESS_RES_TYPE		9
#define IRK_RESRC_CNTL_RES_TYPE		10

/*
 * Error and warning codes
 */
#define IRK_NO_ERROR			0

#define IRK_MEMORY_ERROR 		101
#define IRK_PLI_ERROR			102
#define IRK_PROTOCOL_ERROR 		103
#define IRK_COMMS_ERROR			104

#define IRK_ASSOC_ALREADY_EXISTS 	200
#define IRK_ASSOC_DOES_NOT_EXIST	201
#define IRK_INVALID_EVENT		202
#define IRK_EVENT_NOT_SUPPORTED		203
#define IRK_INVALID_EVENT_FOR_STATE	204

/*
 * Send request structure.
 */
typedef struct
{
	APDU			irApdu;
} IRK_SEND_REQUEST_REQ;

/****************************************************************************
 * Communication Event Types:
 ****************************************************************************/

/*
 * Communication Event request structure. This interface is
 * used in both polled and event driven applications.
 */

typedef struct
{
	IR_ASSOC_ID	assocId;
	CHAR		*event;
} IRK_COMM_EVENT_REQ;

/* 
 * Communication Event reply structure.
 */
typedef struct
{
	IR_ASSOC_ID			assocId;
	IR_COMM_EVENT_STATUS		replyType;
	APDU 				*apdu;
	VISIBLE_STRING			targetAddress;
} IRK_COMM_EVENT_REPLY;
	
/****************************************************************************
 * Association Types:
 ****************************************************************************/

/*
 * Association Information Request Structure.
 */
typedef struct
{
	IR_ASSOC_ID		assocId;  /* Established assoc */
	VISIBLE_STRING		hostName;	  /* Null if not used */
	VISIBLE_STRING		hostAddr;	  /* Null if not used */
	USHORT			portNum;	  /* Port to use */
} IRK_ASSOC_REQ;

/* 
 * Association Information Reply Structure.
 */
typedef struct
{
	IR_ASSOC_ID		assocId;	/* Connected Assoc */
} IRK_ASSOC_REPLY;

/****************************************************************************
 * Kernel Configuration Types:
 ****************************************************************************/

typedef struct
{
	IR_COMM_CONFIGURATION		commConfig;
	BOOLEAN				debugLog;
	BOOLEAN				logAPDUs;
} IRK_INIT_REQ;

/****************************************************************************
 * Error report requests.
 ****************************************************************************/
/*
 * Error report of most recent error.
 */
#define IRK_MAX_ERROR_SOURCE	101

typedef struct
{
	IR_ERROR_LEVEL	errorLevel;
	IR_ERROR_CODE	errorCode;
	CHAR		errorSource[IRK_MAX_ERROR_SOURCE];
} IRK_ERROR_REPLY;

/****************************************************************************
 * Prototypes for Interface primitives:
 ****************************************************************************/

IR_STATUS	IRK_SendRequest( IRK_REQ_SERVICE_TYPE event,
		    IR_ASSOC_ID assocId,
		    IRK_SEND_REQUEST_REQ *requestReq);

IR_STATUS	IRK_CommEvent( IRK_COMM_EVENT_REQ *commRequest,
		    IRK_COMM_EVENT_REPLY *commReply);

IR_STATUS	IRK_Association( IRK_ASSOC_REQ *request,
		    IRK_ASSOC_REPLY *reply);

IR_STATUS	IRK_Initialize( IRK_INIT_REQ *initReq);

IR_STATUS	IRK_Terminate();

IR_STATUS	IRK_ErrorReport( IRK_ERROR_REPLY *error);
#endif
