
/************************************************************************
 *
 * SR/Z3950 application software version 1.0, August 1993.
 *
 * (C) Software Kinetics Ltd.
 *
 * Software Kinetics Ltd. has granted a licence of this software to the
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve, reproduce
 * and sell the software.
 *
 * The software is provided to the user "as is" without warranty of any
 * kind. Neither Software Kinetics Ltd. nor the National Library of Canada
 * warrants, guarantees or makes any representations regarding the use,
 * or the results of use of the software in terms of accuracy, reliability,
 * or otherwise. The entire risk as to results and performance of the
 * software is assumed by the user. Neither Software Kinetics Ltd. nor the
 * National Library of Canada shall be liable for any direct, indirect,
 * consequential or incidental damages arising out of the use of the
 * software.
 *
 ************************************************************************/

/****************************************************************************
 * HEADER ir_api.h
 *
 * PURPOSE:
 *	This header file is the general Application Programming Interface
 *	file. 
 *
 * SCOPE:
 *	All Origin Process CSCs that use API data types must include this
 *	file. All Application CSCs that invoke API primitives must include
 *	this file.
 *
 * CONTENTS:
 *	- API Data structures.
 *		- IRO_Initialize structures
 *		- IRO_CommEvent structures
 *		- IRO_Association structures
 *		- IRO_Search structures
 *		- IRO_Present structures
 *		- IRO_WorkSpaceInfo structures
 *		- IRO_Delete structures
 *		- IRO_AccessControl structures
 *		- IRO_ResourceControl structures
 *		- IRO_TriggerControl structures
 *		- IRO_ResourceReport structures
 *		- IRO_UserInfo structures
 *		- IRO_TargetInfo structures
 *		- IRO_DatabaseInfo structures
 *		- IRO_ErrorReport structures.
 *	- Prototypes
 *
 * NOTES:
 * 	All data pointers specified in the interface structures are
 *	memory allocated data structures. It is the responsibility of
 *	the calling application to free this memory when it is done
 *	with it. 
 * 
 *
 * $Log:
 * Revision 1.1  1993/09/16  09:03:27  irorigin
 * Baseline for Release 1.0.
 *
 ****************************************************************************/

#ifndef IR_API_H

#define IR_API_H
#include <ir.h>


/* 
 * IRO Function types for error reporting.
 */

#define IRO_INITIALIZE_FUNC		1
#define IRO_COMM_EVENT_FUNC		2
#define IRO_ASSOCIATION_FUNC		3
#define IRO_ABORT_FUNC			4
#define IRO_TERMINATE_FUNC		5
#define IRO_SEARCH_FUNC			6
#define IRO_PRESENT_FUNC		7
#define IRO_DELETE_FUNC			8
#define IRO_WORKSPACEINFO_FUNC		9
#define IRO_ACCESSCONTROL_FUNC		10
#define IRO_RESOURCECONTROL_FUNC 	11
#define IRO_TRIGGERCONTROL_FUNC		12
#define IRO_RESOURCEREPORT_FUNC		13
#define IRO_USERINFO_FUNC		14
#define IRO_TARGETINFO_FUNC		15
#define IRO_DATABASEINFO_FUNC		16

typedef SHORT	IRO_FUNC_NAME;
typedef SHORT	IRO_FUNC_REC_TYPE;

/****************************************************************************
 * Initialize requests.
 ****************************************************************************/

typedef struct
{
	IR_COMM_CONFIGURATION	commConfig;
	IR_LANG_CONFIGURATION	langConfig;
	BOOLEAN			debugLog;
	BOOLEAN			logAPDUs;
	BOOLEAN			isMalloced;
} IRO_INIT_REQ;
	

/****************************************************************************
 * Communication Event request and reply.
 ****************************************************************************/

typedef SHORT	IRO_WORK_SPACE_ID;

typedef struct
{
	BOOLEAN			searchStatus;
	IR_RESULT_SET_STATUS	resultSetStatus;
	IR_PRESENT_STATUS	presentStatus;
	IRO_WORK_SPACE_ID	wsId;
	IR_DIAG_RECORD		diagnostic;	/* On err. */
	LONG			numRecInWs;	/* Used by amicus */
	LONG			numRecOnTarget;	/* Used by amicus */
	LONG			nextPosOnTarget; /* Used by amicus */
	BOOLEAN			isMalloced;
} IRO_COMM_SRCH_RESP;

typedef struct
{
	IR_PRESENT_STATUS	presentStatus;
	IRO_WORK_SPACE_ID	wsId;
	IR_DIAG_RECORD		diagnostic;	/* On err. */
	LONG			numRecInWs;	/* Used by amicus */
	LONG			numRecOnTarget;	/* Used by amicus */
	LONG			numRecRetrieved;/* Used by amicus */
	LONG			nextPosOnTarget; /* Used by amicus */
	BOOLEAN			isMalloced;
} IRO_COMM_PRSNT_RESP;

/*
 * Access Control Request. Based on Access Control request APDU.
 */
typedef struct
{
	OCTET_STRING		accessControlReq;
	BOOLEAN			isMalloced;
} IRO_COMM_ACCS_CNTL_REQ;

/*
 * Resource Report based on bib-1 information 
 * as specified in bib-1 appendix F of ANSI Z39.50-1992.
 */
typedef struct
{
	SHORT		estimateType;	/* Bib-1 */
	ULONG		value;		/* Bib-1 */
	ULONG		currency;	/* Bib-1 */
	BOOLEAN		knownCurrency;	/* currency is optional */
	BOOLEAN		isMalloced;
} IRO_COMM_RSRC_RPRT_EST;

typedef struct
{
	IR_LIST			estimates; /* List of IRO_COMM_RSRC_RPRT_EST */
	VISIBLE_STRING		message;
	OBJECT_IDENTIFIER	oid;	   /* String Form of OID */
	SHORT			reportStatus;
	BOOLEAN			isMalloced;
} IRO_COMM_RSRC_REPORT;
	
/*
 * Resource Control Request. Based on APDU information.
 */
typedef struct
{
	IRO_COMM_RSRC_REPORT	*resourceReport;	/* Null if not used */
	BOOLEAN			targetCmdSuspended;
	BOOLEAN			responseRequired;
	BOOLEAN			triggeredRequest;
	IR_RESULT_SET_STATUS	partialResultsAvail;
	BOOLEAN			isMalloced;
} IRO_COMM_RSRC_CNTL_REQ;
	
typedef struct
{
	IR_DELETE_SET_STATUS	deleteStatus;
	IR_LIST			statusList;	/* IR_DELETE_STATUS_STRUCT */
	LONG			numberNotDeleted;
	IR_LIST			bulkStatusList;	/* IR_DELETE_STATUS_STRUCT */
	VISIBLE_STRING		deleteMessage;
	BOOLEAN			isMalloced;
} IRO_COMM_DEL_RESP;

typedef struct
{
	VISIBLE_STRING	protocolVersion;
	BOOLEAN		search;
	BOOLEAN		present;
	BOOLEAN		delSet;
	BOOLEAN		resourceReport;
	BOOLEAN		triggerResourceCtrl;
	BOOLEAN		resourceCtrl;
	BOOLEAN		accessCtrl;
	LONG		preferredMessageSize;
	LONG		maximumRecordSize;
	VISIBLE_STRING	implementationId;
	VISIBLE_STRING	implementationName;
	VISIBLE_STRING	implementationVersion;
	VISIBLE_STRING	userInfo;
	BOOLEAN		isMalloced;
} IRO_COMM_INIT_RESP;

/*
 * Communication Service event request. This request is application
 * dependant code that is initially defined for a MS Windows enironment
 * using either a polled or event driven configuration. In an event
 * driven configuration the association identifier is used to identify
 * the association that generated the event. The eventInfo will
 * be a pointer to event information as defined in Windows Sockets API.
 * This includes wHnd, wMsg, wParam, and lParam embeded within a structure
 * in the order specified. The reason this structure is not defined here
 * is because the data involved is application dependant and is only
 * required by the communication services and the user application.
 */
typedef struct
{
	IR_ASSOC_ID		assocId;
	CHAR			*eventInfo;	/* Null if polled */
	BOOLEAN			isMalloced;
} IRO_COMM_EVENT_REQ;	

/*
 * Communication event return data.
 */
typedef union
{
	IRO_COMM_ACCS_CNTL_REQ		accessCntlReq;
	IRO_COMM_RSRC_CNTL_REQ		resourceCntlReq;
	IRO_COMM_SRCH_RESP		searchResponse;
	IRO_COMM_PRSNT_RESP		presentResponse;
	IRO_COMM_DEL_RESP		deleteResponse;
	IRO_COMM_RSRC_REPORT		resourceReport;
	IRO_COMM_INIT_RESP		initResponse;
} IRO_COMM_EVENT_UNION;

/*
 * Communication Event Reply.
 */
typedef struct
{
	IR_ASSOC_ID			assocId;		
	IR_COMM_EVENT_STATUS		commReplyType;
	IRO_COMM_EVENT_UNION		commData;
	BOOLEAN				isMalloced;
} IRO_COMM_EVENT_REPLY;

/****************************************************************************
 * Association requests and replies.
 ****************************************************************************/

/*
 * Association request types.
 */
typedef SHORT		IRO_ASSOC_REQ_TYPE;

#define IRO_ASSOC_ESTABLISH		0	/* establish an assoc */
#define IRO_ASSOC_TERMINATE		1	/* terminate an assoc */
#define IRO_ASSOC_ABORT			2	/* abort an assoc */
#define IRO_ASSOC_GET_ASSOC_INFO	3	/* brief list of all assoc */
#define IRO_ASSOC_FULL_INFO		4	/* Full info for single assoc */

/* 
 * The address types are used to identify the source of the
 * target's address when establishing an association.
 */
typedef SHORT	IRO_ASSOC_ADDR_TYPE;

#define IRO_ASSOC_ADDR_TARGET_ID	1	/* Origin Process Tables */

/*
 * The association state is used to identify any activity that
 * may be outstanding on the target.
 */
typedef SHORT IRO_ASSOC_STATE;

#define IRO_ASSOC_STATE_IDLE		0
#define IRO_ASSOC_STATE_CONNECT		1
#define IRO_ASSOC_STATE_INIT		2
#define IRO_ASSOC_STATE_SEARCH		3
#define IRO_ASSOC_STATE_PRESENT		4
#define IRO_ASSOC_STATE_DELETE		5
#define IRO_ASSOC_STATE_RSRC_RPRT	6
#define IRO_ASSOC_STATE_UNASSOCIATED	7
#define IRO_ASSOC_STATE_ABORTING	8


/*
 * Association Information Request Structure.
 */
typedef struct
{
	IR_ASSOC_ID		assocId;		
	IR_TARGET_ID		targetId;
	IRO_ASSOC_ADDR_TYPE	nameType;
	BOOLEAN			isMalloced;
} IRO_ASSOC_REQ;

/*
 * Association Reply structure (brief). This information is returned by the
 * Origin Process when obtaining a list of existing associations.
 */
typedef struct ASSOC_INFO
{
	IR_ASSOC_ID		assocId;
	IR_TARGET_ID		targetId;
	VISIBLE_STRING		name;
	VISIBLE_STRING		address;
	VISIBLE_STRING		hostName;
	IRO_ASSOC_STATE		state;
	BOOLEAN			isMalloced;
} IRO_ASSOC_STRUCT;


/*
 * Association Reply structure (full). This information is returned by the
 * Origin Process when obtaining a all information for an existing 
 * association.
 */
typedef struct
{
	IRO_ASSOC_STRUCT	assocStruct;
	IRO_COMM_INIT_RESP	initResp;
	BOOLEAN			isMalloced;
} IRO_ASSOC_FULL_INFO_STRUCT;

/* 
 * Association Information Reply Structure.
 */
typedef struct
{
	IR_LIST				*activeAssociations;	/* List of IRO_ASSOC_STRUCT */
	IRO_ASSOC_FULL_INFO_STRUCT	*fullInfo;	/* Full information for single assoc */
	BOOLEAN		isMalloced;
} IRO_ASSOC_REPLY;

/****************************************************************************
 * Search request.
 ****************************************************************************/

/*
 * Search request structures.
 */
typedef struct
{
	IR_ASSOC_ID		assocId;
	LONG			smallSetUpperBound;	/* -1 for default */
	LONG			largeSetLowerBound;	/* -1 for default */
	LONG			mediumSetPresentNum;	/* -1 for default */
	BOOLEAN			replaceIndicator;	/* if supported */
	VISIBLE_STRING		resultSetName;		/* must at least 
							   say default */
	IR_LIST			dbNameList;		/* Database list 
							 * Visible string 
							 */
	IR_ELEM_SET_NAME_TYPE	smallSetNameType;
	IR_ELEM_SET_NAMES	smallSetList;		/* Optional list 
							 * Visible string 
							 */
	IR_ELEM_SET_NAME_TYPE	mediumSetNameType;	
	IR_ELEM_SET_NAMES	mediumSetList;		/* Optional list
							 * Visible string 
							 */
	OBJECT_IDENTIFIER	recordSyntax;		/* ie US MARC */
	IR_QUERY_TYPE		queryType;		/* Query Type (RPN) */
	IR_RPN_QUERY_STRUCT	query;			/* term and op list */
	BOOLEAN			isMalloced;
} IRO_SEARCH_REQ;
	
/****************************************************************************
 * Present requests.
 ****************************************************************************/

/*
 * Present request structures. Target only.  
 */
typedef struct
{
	IR_ASSOC_ID		assocId;
	IRO_WORK_SPACE_ID	wsId;
	VISIBLE_STRING		resultSetName;	/* optional - default */
	LONG			startRec;	/* Start record on target */
	LONG			numRecords;	/* num records from target */
	IR_ELEM_SET_NAME_TYPE	elemSetNameType;
	IR_ELEM_SET_NAMES	elemSetList;		/* Optional list 
							 * Visible string 
							 */
	OBJECT_IDENTIFIER	recordSyntax;	/* US MARC */
	BOOLEAN			isMalloced;
} IRO_PRESENT_REQ;


/****************************************************************************
 * WorkSpace Information requests.
 ****************************************************************************/

/*
 * WorkSpace Information request types.
 */
typedef SHORT		IRO_WS_INFO_TYPE;

#define IRO_WS_INFO_HEADER		0	/* Get General information */
#define IRO_WS_INFO_SEARCH		1	/* Get Search request */

#define IRO_WS_INFO_REC_ALL		3	/* Get all records */
#define IRO_WS_INFO_REC_PARTIAL		4	/* Get n records */
#define IRO_WS_INFO_REC_SPECIFIC	5	/* Get specific */
#define IRO_WS_INFO_REC_DIAG		6	/* Get Non surr diag for a
					 	 * search or present
						 */
#define IRO_WS_INFO_GEN_ALL		7	/* Get All general information 
						 * for a workspace. 
						 */

typedef struct 
{
	IRO_WORK_SPACE_ID	wsId;			
	VISIBLE_STRING		name;			/* result set name */
	IR_ASSOC_ID		assocId;		/* association used */
	LONG			totalTargetRecords;	/* Target count */
	LONG			numWSRecords;		/* origin only */
	LONG			nextTargetRec;		/* Target next pos */
	BOOLEAN			searchStatus;		/* Search response */
	IR_RESULT_SET_STATUS	resultSetStatus;	/* Search response */
	IR_DIAG_RECORD		nonSurrDiag;		/* latest diagnostic rec */
	LONG			numRecReturned;		/* most recent service 
							 * call.
							 */
	IR_PRESENT_STATUS	presentStatus;		/* ditto */
	BOOLEAN			targetResultsDeleted;
	BOOLEAN			presentSrvcSupported;
	BOOLEAN			deleteSrvcSupported;
	BOOLEAN			presenting;
	BOOLEAN			deleting;
	BOOLEAN			isMalloced;
} IRO_WS_HEADER_INFO;

/*
 * General WorkSpace information.
 */
typedef struct
{
	IR_LIST			wsHeaderInfo;	/* List of IRO_WS_HEADER_INFO */
	BOOLEAN			isMalloced;
} IRO_WS_GEN_INFO;

/* Unique record identifier on a per search basis */
typedef SHORT IRO_TARGET_REC_ID;

/*
 * WorkSpace Information request structure.
 */
typedef struct
{
	IRO_WORK_SPACE_ID	wsId;
	SHORT			startItem;
	IR_LIST			recList;	/* IRO_TARGET_REC_ID */
	BOOLEAN			isMalloced;
} IRO_WORK_SPACE_REQ;

/* 
 * WorkSpace Information reply structure.
*/
typedef struct
{
	IRO_WS_GEN_INFO		*genInfo;	/* General information */
	IRO_SEARCH_REQ		*searchInfo;	/* Query List info */
	IR_LIST			*records;	/* list of IR_RECORD_STRUCT */
	VISIBLE_STRING		diagnostic;	/* last non surrogate 
						 * diagnostic info */
	BOOLEAN			isMalloced;
} IRO_WORK_SPACE_REPLY;

/****************************************************************************
 * Delete requests.
 ****************************************************************************/

typedef SHORT	IRO_DELETE_TYPE;

/* Delete Operations */
#define IRO_DELETE_WS_REC_ALL		0	/* all records in a wrk space */
#define IRO_DELETE_WS_REC_SPEC		1	/* specific records in a wrk space */
#define IRO_DELETE_TARGET_RSLTS		2	/* Target result set */
#define IRO_DESTROY_WS			3	/* Remove work space. */

/*
 * Delete request.
 */
typedef struct
{
	IR_ASSOC_ID			assocId;
	IRO_WORK_SPACE_ID		wsId;
	IR_LIST				wsList;		/* WS List to delete */
	IR_DELETE_SET_FUNCTION		deleteFunc;
	BOOLEAN				isMalloced;
} IRO_DELETE_REQ;


/****************************************************************************
 * Access Control, Resource Control, Trigger Resource Control
 * and Resource Report requests.
 ****************************************************************************/

/*
 * Resource and Access Control requests.
 */
typedef struct
{
	/* Target issued the request. Origin responds. */
	IR_ASSOC_ID		assocId;
	VISIBLE_STRING		accessResponse;	
	BOOLEAN				isMalloced;
} IRO_ACCESS_CNTRL_REQ;

typedef struct
{
	IR_ASSOC_ID	assocId;
	BOOLEAN		continueFlag;
	BOOLEAN		resultSetWanted;	/* Required for search only */
	BOOLEAN		wantedFlagValid;
	BOOLEAN		isMalloced;
} IRO_RSRC_CNTRL_REQ;


typedef SHORT	IRO_TRIGGER_CNTL_OPER;

#define IRO_TRIGGER_RSRC_RPRT	0
#define IRO_TRIGGER_RSRC_CNTL	1
#define IRO_TRIGGER_CANCEL	2

typedef struct
{
	IR_ASSOC_ID			assocId;
	IRO_TRIGGER_CNTL_OPER		operation;
	OBJECT_IDENTIFIER		resourceReportFmt;
	BOOLEAN				resultSetWanted;
	BOOLEAN				isMalloced;
} IRO_TRIGGER_CNTRL_REQ;

typedef struct
{
	/* Origin issues resource report request. */
	IR_ASSOC_ID			assocId;
	OBJECT_IDENTIFIER		rsrcRprtFmt;
	BOOLEAN				isMalloced;
} IRO_RSRC_RPRT_REQ;

/****************************************************************************
 * User Information requests.
 ****************************************************************************/

/*
 * User Information requests types.
 */
typedef SHORT	IRO_USER_INFO_TYPE;

#define IRO_UI_LOGIN			0	/* verify name and password */
#define IRO_UI_VERIFY_PASSWORD		1	/* verify password */
#define IRO_UI_CHANGE_PASSWORD		2	/* Change Password */
#define IRO_UI_ACCOUNT			3	/* Get user info */
#define IRO_UI_ADMIN_ACCOUNTS		4	/* Get list of users */
#define IRO_UI_GET_USERS		5	/* Get list of origin users */
#define IRO_UI_TARGETS			6	/* Get targets for user */

typedef struct
{
	IR_USER_ID		myUserId;	/* User to get target info */
	VISIBLE_STRING		loginPassword;	/* Login user or change password */
	VISIBLE_STRING		loginName;
	BOOLEAN			isMalloced;
} IRO_USER_INFO_REQ;

/*
 * User login information. Reply information.
 */
typedef struct
{
	IR_USER_ID		userId;
	IR_USER_PRIV_TYPE	privilege;
	IR_LANG_CONFIGURATION	prefLang;
	BOOLEAN			isMalloced;
} IRO_USER_LOGIN;

/*
 * Reply with one of the following. 
 */
typedef struct
{
	IRO_USER_LOGIN		*loginInfo;	
	IR_LIST			*targetInfo;	/* IR_USER_TARGET_INFO list */
	IR_LIST			*genInfo;	/* IR_USER_GEN_INFO list */
	BOOLEAN			isMalloced;
} IRO_USER_INFO_REPLY;

/****************************************************************************
 * Target Tables requests.
 ****************************************************************************/

/*
 * Target Information requests.
 */
typedef SHORT	IRO_TARGET_INFO_TYPE;

#define IRO_TRGT_INFO_GEN		0	/* Get General Target info */
#define IRO_TRGT_INFO_ASSOC		1	/* Get Target Assoc Info */

typedef union
{
	IR_TARGET_ASSOC_INFO	*targetAssocInfo;/* target assoc info */
	IR_TARGET_INFO		*targetGenInfo;	/* target info. */
} IRO_TARGET_INFO_REPLY;
	

/****************************************************************************
 * Database Tables requests.
 ****************************************************************************/

/*
 * Database Information requests.
 */
typedef SHORT	IRO_DB_INFO_TYPE;

#define IRO_DB_INFO_ALL			0	/* All DB Info for a target */
#define IRO_DB_INFO_SINGLE		1	/* Single DB info for a target */

typedef struct
{
	IR_TARGET_ID		targetId;	/* Always required */
	VISIBLE_STRING		dbName;		/* database name */
	BOOLEAN			isMalloced;
} IRO_DB_INFO_REQ;

typedef struct
{
	IR_LIST			*dbInfo;	/* List of IR_DATABASE_INFO */
	BOOLEAN			isMalloced;
} IRO_DB_INFO_REPLY;

/****************************************************************************
 * Error report requests.
 ****************************************************************************/
/*
 * Error and warning codes.
 */
#define	IRO_NO_ERROR		0
#define IRO_MEMORY_ERROR	1001
#define IRO_ALI_ERROR		1002
#define IRO_PROTOCOL_ERROR	1003
#define IRO_COMMS_ERROR		1004
#define IRO_ASSOC_DOES_NOT_EXIST	2001
#define IRO_ASSOC_ALIVE_TERM		2002
#define IRO_ASSOC_BUSY			2003
#define IRO_ASSOC_NOT_BUSY		2004
#define IRO_DATA_ERROR			3001
#define IRO_QUERY_TYPE_NOT_SUPPORTED	3002
#define IRO_RPN_QUERY_ERROR		3003
#define IRO_WORKSPACE_DOES_NOT_EXIST	3004
#define IRO_NO_CURRENT_SEARCH		3005
#define IRO_UNKNOWN_USER_ID		3006
#define IRO_UNKNOWN_ADDR_TARGET_TYPE	3007
#define IRO_UNKNOWN_OID			3008
#define IRO_UNSUPPORTED_REQ_TYPE	3009
#define IRO_TARGET_STILL_CONNECTED	3010
#define IRO_UNKNOWN_DELETE_TYPE		3011
#define IRO_NO_RESULTS_FOR_DELETE	3012
#define IRO_REQ_SERVICE_NOT_SUPPORTED	3013

#define IRO_FILE_OPEN_ERROR 	4000
#define IRO_FILE_CLOSE_ERROR	4001
#define IRO_FILE_READ_ERROR	4002
#define IRO_INVALID_PASSWORD	4003
#define IRO_PERMISSION_DENIED	4004
#define IRO_USER_UNKNOWN	4005
#define IRO_TARGET_UNKNOWN	4006
#define IRO_FILE_WRITE_ERROR    4007
#define IRO_DATABASE_UNKNOWN	4008
#define IRO_USER_CURRENTLY_LOGGED_IN 4009

#define IRO_NO_DELETE_LIST_SPECIFIED 	5000

#define IRO_MAX_ERROR_STRING	100

/*
 * report of most recent error.
 */
typedef struct
{
	IR_ERROR_LEVEL 	errorLevel;
	IR_ERROR_CODE	errorCode;
	CHAR		errorString[IRO_MAX_ERROR_STRING+1];	
	BOOLEAN		isMalloced;
} IRO_ERROR_REPLY;

/****************************************************************************
 * Prototypes for Interface primitives:
 ****************************************************************************/


IR_STATUS	IRO_Initialize( IRO_INIT_REQ *startupReq );

IR_STATUS	IRO_CommEvent( IRO_COMM_EVENT_REQ *commEvent,
		    IRO_COMM_EVENT_REPLY **commReply );

IR_STATUS	IRO_Association( IR_USER_ID userId, 
		    IRO_ASSOC_REQ_TYPE reqType,
		    IRO_ASSOC_REQ *assocReq,
		    IRO_ASSOC_REPLY *assocReply );

IR_STATUS	IRO_Terminate();

IR_STATUS	IRO_Search( IR_USER_ID userId, IRO_SEARCH_REQ *searchStruct );

IR_STATUS	IRO_Present( IR_USER_ID userId, 
		    IRO_PRESENT_REQ *presentStruct );

IR_STATUS	IRO_Delete( IR_USER_ID userId, IRO_DELETE_TYPE deleteType,
		    IRO_DELETE_REQ *deleteStruct );

IR_STATUS	IRO_WorkSpaceInfo( IR_USER_ID userId, 
		    IRO_WS_INFO_TYPE workSpaceType,
		    IRO_WORK_SPACE_REQ *workSpaceReq,
		    IRO_WORK_SPACE_REPLY *workSpaceReply);

IR_STATUS	IRO_AccessControl( IR_USER_ID userId, 
		    IRO_ACCESS_CNTRL_REQ *accessStruct);

IR_STATUS	IRO_ResourceControl( IR_USER_ID userId, 
		    IRO_RSRC_CNTRL_REQ *resourceStruct);

IR_STATUS	IRO_TriggerControl( IR_USER_ID userId,
		    IRO_TRIGGER_CNTRL_REQ *triggerStruct);

IR_STATUS	IRO_ResourceReport( IR_USER_ID userId,
		    IRO_RSRC_RPRT_REQ *resourceStruct);

IR_STATUS	IRO_UserInfo( IRO_USER_INFO_TYPE infoType,
		    IRO_USER_INFO_REQ *userInfoReq,
		    IRO_USER_INFO_REPLY *userInfoReply);

IR_STATUS	IRO_TargetInfo( IR_USER_ID userId, 
		    IRO_TARGET_INFO_TYPE infoType,
		    IR_TARGET_ID targetId,
		    IRO_TARGET_INFO_REPLY *infoReply);

IR_STATUS	IRO_DatabaseInfo( IR_USER_ID userId,
		    IRO_DB_INFO_TYPE infoType,
		    IRO_DB_INFO_REQ *dbInfo,
		    IRO_DB_INFO_REPLY *dbInfoReply);

IR_STATUS	IRO_ErrorReport( IRO_ERROR_REPLY *errorInfo);

#endif
