/************************************************************************
 *
 * Copyright (C) Software Kinetics 1993
 *
 ************************************************************************/
/****************************************************************************
 * HEADER ir_cs.h
 *
 * PURPOSE:
 *	This header file is global to the Communication Service CSC only.
 *
 * SCOPE:
 *	
 * NOTES:
 *
 * 
 * $Log:
 * Revision 1.1  1993/09/16  09:03:27  irorigin
 * Baseline for Release 1.0.
 *
 ****************************************************************************/

#ifndef IR_CS_H

#define IR_CS_H
#include <ir.h>
#include <ir_pli.h>
#include <ir_net.h>
#include <debug.h>
#include <resc.h>
#include <resclist.h>

#ifdef WINSOCKET
#include <windows.h>
#else
#ifndef WM_USER
#define WM_USER 40
#endif
#endif

#ifndef SOCKET
#if defined(BSDSOCKET) || defined(WINPATHWAY)
typedef int SOCKET;
#endif
#endif
/*
 * CS Error codes.
 */
#define	CS_ERR_IRC_NOT_INIT		1
#define CS_ERR_NO_SOCK_ITEM		2
#define CS_ERR_SELECT			3
#define CS_ERR_IRC_SEND_ERROR		4
#define CS_ERR_CONNECT_FAIL		5
#define CS_ERR_IOCTL_ERROR		6
#define CS_ERR_CONN_WOULD_BLOCK		7


#define NO_STRING		""
#define NO_DATA_VALUE		(-10)


/* CS Buffer size */
#define CS_MAX_RD_BUF_SIZE	2048

typedef USHORT CS_SOCK_EVENT;

#define CS_SOCK_EV_NONE		(WM_USER + 1)
#define CS_SOCK_EV_RESOLVED	(WM_USER + 2)
#define CS_SOCK_EV_CONNECTED	(WM_USER + 3)
#define CS_SOCK_EV_RECV		(WM_USER + 4)
#define CS_SOCK_EV_SEND		(WM_USER + 5)
#define CS_SOCK_EV_USER_RELEASE (WM_USER + 6)
#define CS_SOCK_EV_USER_ABORT	(WM_USER + 7)
#define CS_SOCK_EV_ERROR_ABORT	(WM_USER + 8)
#define CS_SOCK_EV_LOST_CONNECT (WM_USER + 9)
#define CS_SOCK_EV_FAIL_RESOLVE (WM_USER + 10)
#define CS_SOCK_EV_CONN_REFUSED	(WM_USER + 11)
#define CS_SOCK_EV_POLL		(WM_USER + 12)
#define CS_SOCK_EV_RWC		(WM_USER + 13)

typedef SHORT CS_SOCK_STATE;
#define CS_SOCK_ST_CLOSED	(-1)
#define CS_SOCK_ST_INIT		1
#define CS_SOCK_ST_RESOLVE	2
#define CS_SOCK_ST_CONNECT	3
#define CS_SOCK_ST_OPER		4
#define CS_SOCK_ST_ABORT	5

/*
 * Send/Recieve buffer structure. 
 */

#define CS_BUF_ST_EMPTY			0x0000
#define CS_BUF_ST_START_APDU		0x0001
#define CS_BUF_ST_END_APDU		0x0002
#define CS_BUF_ST_IDEF_APDU		0x0004
#define CS_BUF_ST_DEF_APDU		0x0008
#define CS_BUF_ST_SEND_DATA		0x0010

typedef struct SEND_BUF
{
	USHORT		bufMallocSize;		/* Used by buff routines only */
	USHORT		bufSize;		/* Used by send and recv. */
	USHORT		numSent;		/* Used by Send only. */
	USHORT		bufState;		/* state of buffer info. */
	USHORT		sizeOfAPDU;		/* Used by send or recv. */
	CHAR		*buf;
	BOOLEAN		isMalloced;
} CS_BUFFER;

/*
 * A single socket item. 
 */
typedef struct SOCK_ITEM
{
	SOCKET			socketFd;
	CS_SOCK_STATE		state;
	IR_ASSOC_ID		assocId;
	USHORT			port;
	HANDLE			handle;
	struct hostent		*hostp;
	IR_LIST			sendList;
	IR_LIST			readList;
	BOOLEAN			isMalloced;
} CS_SOCK_ITEM;
	
/* 
 * Prototypes.
 */
void 		CsCf_AssocInit(IRC_INIT_REQ *initReq );
CS_SOCK_ITEM	*CsCf_AssocNew(IR_ASSOC_ID);
CS_SOCK_ITEM	*CsCf_AssocGet(IR_ASSOC_ID assocId);
IR_STATUS 	CsCf_AssocDel(IR_ASSOC_ID assocId); 
void		CsCf_Connect(IR_COMM_EVENT *event);
IR_ASSOC_ID 	CsCf_AssocGetFirst();
IR_ASSOC_ID 	CsCf_AssocGetNext(IR_ASSOC_ID assocId);
IR_COMM_EVENT_STATUS CsCf_Poll(IR_ASSOC_ID assocId, CS_SOCK_EVENT event);
BOOLEAN		CsCf_IsIRCInitialized();
IR_COMM_EVENT_STATUS CsCf_ReadData(CS_SOCK_ITEM *sockItem);
IR_COMM_EVENT_STATUS CsCf_SendData(CS_SOCK_ITEM *sockItem);
IR_COMM_EVENT_STATUS CsCf_ReadEvent(IR_ASSOC_ID assocId);
IR_COMM_EVENT_STATUS CsCf_WriteEvent(IR_ASSOC_ID assocId);
IR_COMM_EVENT_STATUS CsCf_CloseEvent(IR_ASSOC_ID assocId);
BOOLEAN	CsCf_IsIRCPolled();


void 		CsCf_BuffInit();
CS_BUFFER 	*CsCf_BuffAlloc();
void		CsCf_BuffFree( CS_BUFFER *buf);
IR_STATUS 	CsCf_StreamToApdu(IR_LIST *, APDU **apdu);

IR_STATUS	CsCf_Notify(IR_ASSOC_ID assocId, CS_SOCK_EVENT event);

void		CsCf_IRExtInit();
BOOLEAN		CsCf_IRExtIsOk();
void		CsCf_DisplayAPDU(APDU *);

void		CsCf_ReportError(CHAR *, SHORT code, CHAR *str, int data);
#endif
