
/************************************************************************
 *
 * SR/Z3950 application software version 1.0, August 1993.
 *
 * (C) Software Kinetics Ltd.
 *
 * Software Kinetics Ltd. has granted a licence of this software to the
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve, reproduce
 * and sell the software.
 *
 * The software is provided to the user "as is" without warranty of any
 * kind. Neither Software Kinetics Ltd. nor the National Library of Canada
 * warrants, guarantees or makes any representations regarding the use,
 * or the results of use of the software in terms of accuracy, reliability,
 * or otherwise. The entire risk as to results and performance of the
 * software is assumed by the user. Neither Software Kinetics Ltd. nor the
 * National Library of Canada shall be liable for any direct, indirect,
 * consequential or incidental damages arising out of the use of the
 * software.
 *
 ************************************************************************/


/****************************************************************************
 * HEADER ir_oid.h
 *
 * PURPOSE:
 *    This header file contains the ASN.1 Object Identifiers used
 *    by this implementation of the IR Z39.50 version 2 1992 standard.
 *
 * SCOPE:
 *    All IR CSCs which reference object identifiers.
 *    
 * NOTES:
 *    The object identifiers defined in this header have been extracted
 *    from the ANSI Z39.50-1992 version 2 standard - appendix A.
 *
 * $Log:
 * Revision 1.1  1993/09/16  09:03:27  irorigin
 * Baseline for Release 1.0.
 *
 * 
 ****************************************************************************/

#ifndef IR_OID_H

#define IR_OID_H


/****************************************************************************
 * IR OID Constants: 
 ****************************************************************************/

/* Object Identifier classes known to this application. */
#define OID_CLASS_APPLICATION_CONTEXT        "1.2.840.10003.1"
#define OID_CLASS_ABSTRACT_SYNTAX        "1.2.840.10003.2"
#define OID_CLASS_ATTRIBUTE_SET            "1.2.840.10003.3"
#define OID_CLASS_DIAGNOSTIC_SET        "1.2.840.10003.4"
#define OID_CLASS_ABSTRACT_RECORD_SYNTAX    "1.2.840.10003.5"
#define OID_CLASS_XFER_SYNTAX_NON_BIB        "1.2.840.10003.6"
#define OID_CLASS_RESOURCE_REPORT_FORMAT    "1.2.840.10003.7"
#define OID_CLASS_ACCESS_CONTROL    "1.2.840.10003.8"
#define OID_CLASS_USER_INFO_FIELD        "1.2.840.10003.10"

/* Basic Z3950 Application Context OID */
#define OID_APP_CNTXT_BASIC_Z3950        "1.2.840.10003.1.1"

/* Abstract Syntax - Z3950 APDUs */
#define OID_ABSTRACT_SYNTAX_Z3950_APDUS        "1.2.840.10003.2.1"

/* Presentation Context negotiation abstract and transfer syntaxes */
#define OID_PRESENATION_ABS_XFER_SYNTAX        "1.1"

/* Attribute Set OID - Bib1 */
#define OID_ATTRIBUTE_SET_BIB1            "1.2.840.10003.3.1"

/* Diagnostic Set OID - Bib1 */
#define OID_DIAGNOSTIC_SET_BIB1            "1.2.840.10003.4.1"

/* Abstract Record Syntax OIDs - From Appendix E. */
#define OID_REC_SYN_UNIMARC            "1.2.840.10003.5.1"
#define OID_REC_SYN_INTERMARC            "1.2.840.10003.5.2"
#define OID_REC_SYN_CCF                "1.2.840.10003.5.3"
#define OID_REC_SYN_USMARC            "1.2.840.10003.5.10"
#define OID_REC_SYN_UKMARC            "1.2.840.10003.5.11"
#define OID_REC_SYN_NORMARC            "1.2.840.10003.5.12"
#define OID_REC_SYN_LIBRISMARC            "1.2.840.10003.5.13"
#define OID_REC_SYN_DANMARC            "1.2.840.10003.5.14"
#define OID_REC_SYN_FINMARC            "1.2.840.10003.5.15"
#define OID_REC_SYN_MAB                "1.2.840.10003.5.16"
#define OID_REC_SYN_CANMARC            "1.2.840.10003.5.17"
#define OID_REC_SYN_SBN                "1.2.840.10003.5.18"
#define OID_REC_SYN_PICAMARC            "1.2.840.10003.5.19"

/* Transfer Syntax for non-bibliographic records - There are none defined */

/* Resource Report Format OID - Bib1. */
#define OID_RESOURCE_REPORT_FMT_BIB1        "1.2.840.10003.7.1"

/* User Information Field */
#define OID_USER_INFO                	"1.2.840.10003.10.1"

/* Access Control SKL */
#define OID_ACCESS_CTRL_SKL		"1.2.840.10003.8.1000.35.1"

/* Resource Report SKL */
#define OID_RESOURCE_REPORT_FMT_SKL	"1.2.840.10003.7.1000.35.1"

/* IR Defined unrecognized external. Assume it to be a visible string. */
#define OID_IR_UNKNOWN_EXTERNAL_SKL	"1.2.840.10003.1000.35.1"


/*
 * decode/encode/print/free function type identifiers for external 
 * data types.
 */
#define IR_ED_DECODE_FN		1
#define IR_ED_ENCODE_FN		2
#define IR_ED_PRINT_FN		3
#define IR_ED_FREE_FN		4

#endif
