 

/************************************************************************
 *
 * SR/Z3950 application software version 1.0, August 1993.
 *
 * (C) Software Kinetics Ltd.
 *
 * Software Kinetics Ltd. has granted a licence of this software to the
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve, reproduce
 * and sell the software.
 *
 * The software is provided to the user "as is" without warranty of any
 * kind. Neither Software Kinetics Ltd. nor the National Library of Canada
 * warrants, guarantees or makes any representations regarding the use,
 * or the results of use of the software in terms of accuracy, reliability,
 * or otherwise. The entire risk as to results and performance of the
 * software is assumed by the user. Neither Software Kinetics Ltd. nor the
 * National Library of Canada shall be liable for any direct, indirect,
 * consequential or incidental damages arising out of the use of the
 * software.
 *
 ************************************************************************/

/****************************************************************************
 * HEADER ir_pli.h
 *
 * PURPOSE:
 *	This header file is the general presentation layer interface header.
 *
 * SCOPE:
 *	All Communication Service CSCs that use PLI data types must include this
 *	file. All Origin Kernel CSCs that invoke PLI primitives must include
 *	this file.
 *
 * NOTES:
 *
 *
 * $Log:
 * Revision 1.1  1993/09/16  09:03:27  irorigin
 * Baseline for Release 1.0.
 *
 * 
 ****************************************************************************/

#ifndef IR_PLI_H

#define IR_PLI_H

#include <ir.h>
#include <apdu.h>


/****************************************************************************
 * P-Data connection. 
 ****************************************************************************/

/*
 * P-Data structure to send IR Services to a target.
 * This structure is part of the IRC_P_Data primitive.
 */
typedef struct 
{
	APDU		*apdu;
} IRC_P_DATA_SEND;

/****************************************************************************
 * Communication Event Types:
 ****************************************************************************/

/*
 * Communication Event request structure. This interface is
 * used in both polled and event driven applications.
 */

typedef struct
{
	IR_ASSOC_ID	assocId;
	CHAR		*event;
} IRC_COMM_EVENT_REQ;

/* 
 * Communication Event reply structure.
 */
typedef struct
{
	IR_ASSOC_ID			assocId;	/* Always valid */
	IR_COMM_EVENT_STATUS		replyType;	/* always valid */
	APDU				*apdu;		/* P-Data */
	CHAR				*targetAddress;	/* connect address */
} IRC_COMM_EVENT_REPLY;
	
/****************************************************************************
 * Association Types:
 ****************************************************************************/

/*
 * Association Information Request Structure.
 * Either the name or the address is used but not both.
 */
typedef struct
{
	IR_ASSOC_ID		assocId;	/* Established assoc */
	VISIBLE_STRING		hostName;	/* Empty if not used */
	VISIBLE_STRING		hostAddr;	/* Empty if not used */
	USHORT			portNum;	/* Port to use */
} IRC_ASSOC_REQ;

/****************************************************************************
 * Communication Service Configuration Types:
 ****************************************************************************/

typedef struct
{
	IR_COMM_CONFIGURATION		commConfig;
	BOOLEAN				debugLog;
	BOOLEAN				logAPDUs;
} IRC_INIT_REQ;

/****************************************************************************
 * Prototypes for Interface primitives:
 ****************************************************************************/

IR_STATUS	IRC_Connect( IRC_ASSOC_REQ *connReq);

IR_STATUS	IRC_Release( IR_ASSOC_ID assocId );

IR_STATUS	IRC_AbortAssoc( IR_ASSOC_ID assocId );

IR_STATUS	IRC_P_Data( IR_ASSOC_ID assocId, IRC_P_DATA_SEND *pData );

IR_STATUS	IRC_CommEvent( IRC_COMM_EVENT_REQ *commReq,
		    IRC_COMM_EVENT_REPLY *commRep);

IR_STATUS 	IRC_Terminate();

IR_STATUS	IRC_Initialize( IRC_INIT_REQ *initReq );

#endif
