
/************************************************************************
 *
 * SR/Z3950 application software version 1.0, August 1993.
 *
 * (C) Software Kinetics Ltd.
 *
 * Software Kinetics Ltd. has granted a licence of this software to the
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve, reproduce
 * and sell the software.
 *
 * The software is provided to the user "as is" without warranty of any
 * kind. Neither Software Kinetics Ltd. nor the National Library of Canada
 * warrants, guarantees or makes any representations regarding the use,
 * or the results of use of the software in terms of accuracy, reliability,
 * or otherwise. The entire risk as to results and performance of the
 * software is assumed by the user. Neither Software Kinetics Ltd. nor the
 * National Library of Canada shall be liable for any direct, indirect,
 * consequential or incidental damages arising out of the use of the
 * software.
 *
 ************************************************************************/

/****************************************************************************
 * HEADER resclist.h
 *
 * PURPOSE:
 *	This header file contains macros, data structures and prototypes
 *	used to manipulate IR_LIST data elements.
 *
 * SCOPE:
 *	Used by any unit that uses an IR_LIST data element.
 *
 * NOTES:
 *
 * $Log:
 * Revision 1.1  1993/09/16  09:03:27  irorigin
 * Baseline for Release 1.0.
 *
 * 
 ****************************************************************************/

#ifndef IR_RESC_LIST_H
#define IR_RESC_LIST_H
#include <ir.h>
#include <resc.h>

/****************************************************************************
* Macros: 
****************************************************************************/

/* Get macro gets a pointer to the current data element */
#define RESC_LIST_GET(listPtr) (listPtr)->current->elem

#define RESC_LIST_GET_DESTFN(listPtr) (listPtr)->current->destFn
#define RESC_LIST_GET_DUPFN(listPtr) (listPtr)->current->dupFn

/* Check for a valid list element */
#define RESC_LIST_CUR(listPtr) (listPtr)->current

/* get the number of elements in the list */
#define RESC_LIST_SIZE(listPtr) (listPtr)->size

/* Set the current list element pointer to the first element in the list */
#define RESC_LIST_SET_FIRST(listPtr) (listPtr)->current = (listPtr)->first

/* Set the current list element pointer to the last element in the list */
#define RESC_LIST_SET_LAST(listPtr) (listPtr)->current = (listPtr)->last

/* Set the current list element pointer to the next element in the list */
#define RESC_LIST_SET_NEXT(listPtr) \
	{\
		if ((listPtr)->current != (IR_LIST_ELEM *)NULL)\
		{\
			(listPtr)->current = (listPtr)->current->next;\
		}\
	}

/* Set the current list element pointer to the previous element in the list */
#define RESC_LIST_SET_PREV(listPtr) \
	{\
		if ((listPtr)->current != (IR_LIST_ELEM *)NULL)\
		{\
			(listPtr)->current = (listPtr)->current->prev;\
		}\
	}

/* Set the current list element pointer to a specified position in the list */
#define RESC_LIST_SET_CUR(list, pos)\
	{\
		SHORT	iz;\
		RESC_LIST_SET_FIRST(list);\
		for (iz = 0; iz < pos; iz++)\
		{\
			RESC_LIST_SET_NEXT(list);\
		}\
	}

/* Check for current element to be equal to the last element */
#define RESC_LIST_IS_LAST(listPtr) \
	((listPtr)->current == (listPtr)->last)

/* Check for the current element to be equal to the first element */
#define RESC_LIST_IS_FIRST(listPtr) \
	((listPtr)->current == (listPtr)->first))

#define RESC_LIST_INIT(listPtr)\
	{\
		(listPtr)->size = 0;\
		(listPtr)->current = (IR_LIST_ELEM *)NULL;\
		(listPtr)->first = (IR_LIST_ELEM *)NULL;\
		(listPtr)->last = (IR_LIST_ELEM *)NULL;\
	}



/****************************************************************************
 * Prototypes
 ****************************************************************************/

IR_LIST		*RescList_Create(CHAR *srcFile);
IR_STATUS	RescList_Destroy(CHAR *srcFile, IR_LIST *list);
IR_STATUS	RescList_Append(CHAR *srcFile, IR_LIST *list, void *elem,
		    void (*destFn)(), 
		    void *(*dupFn)());
IR_STATUS	RescList_Insert(CHAR *srcFile, IR_LIST *list, void *elem, 
		    void (*destFn)(), void *(*dupFn)(), SHORT pos);
IR_STATUS	RescList_Delete(CHAR *srcFile, IR_LIST *list, SHORT pos);
IR_LIST		*RescList_Clone(CHAR *srcFile, IR_LIST *srcList);
IR_STATUS	RescList_Copy(CHAR *srcFile, IR_LIST *destList, IR_LIST *srcList);

#endif
