
/************************************************************************
 *
 * SR/Z3950 application software version 1.0, August 1993.
 *
 * (C) Software Kinetics Ltd.
 *
 * Software Kinetics Ltd. has granted a licence of this software to the
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve, reproduce
 * and sell the software.
 *
 * The software is provided to the user "as is" without warranty of any
 * kind. Neither Software Kinetics Ltd. nor the National Library of Canada
 * warrants, guarantees or makes any representations regarding the use,
 * or the results of use of the software in terms of accuracy, reliability,
 * or otherwise. The entire risk as to results and performance of the
 * software is assumed by the user. Neither Software Kinetics Ltd. nor the
 * National Library of Canada shall be liable for any direct, indirect,
 * consequential or incidental damages arising out of the use of the
 * software.
 *
 ************************************************************************/

/****************************************************************************
 * HEADER ua.h
 *
 * PURPOSE:
 *      This header file is the general UA include file.  
 *
 * SCOPE:
 *      All UA CSCs must include this header file to ensure that the
 *      correct system wide types are being used.
 *      
 * NOTES:
 *      Character pointers specified in any structure element are null 
 *      terminated ASCII strings unless a count is associated with it.
 *
 *
 * $Log:
 * Revision 1.1  1993/09/16  09:03:27  irorigin
 * Baseline for Release 1.0.
 *
 * 
 ****************************************************************************/

#ifndef UA_H

#define UA_H
#include <ir.h>
#include <ir_api.h>
#include <ua/dialog.h>
#include <ua/ua_rdc.h>
#include <ua/uaepmsg.h>
#ifdef XVT_MSDOS
#include <xvt.h>
#else
typedef SHORT WINDOW;
typedef SHORT FONT;
typedef SHORT PRINT_RCD;
typedef SHORT MENU_TAG;
#endif


/****************************************************************************
 * UA Common Constants and Types:
 ****************************************************************************/
#define UA_FILENAME_SZ      100

typedef CHAR UA_FILENAME[UA_FILENAME_SZ + 1];   /* File name holder. */

typedef SHORT   UA_STATUS;

#define UA_SUCCESS  0
#define UA_FAIL     1

/* Record types used for display purposes */
#define USMARC_REC_TYPE         1       /* Correspond to Object identifiers */
#define CANMARC_REC_TYPE        2


 /*******************************************************************
 * User Application Structures. The information supplied in
 * these structures is based on information specified in the User
 * Application Detailed design.
 *******************************************************************/
/***************************************************
 * Event Processing CSC Data Structures.
 ***************************************************/

/*
 * Dialog Identifier type.
 */
typedef SHORT UAEP_DIALOG_TYPE;


#if 0
typedef struct WORK_SPACE_LIST {
    IRO_WORK_SPACE_ID      wsId;
    IR_ASSOC_ID            assocId;
    WINDOW                 win;
    CHAR                   *wsName;
    SHORT                  availTarget;
    SHORT                  nextTarget;
    SHORT                  availWs;
    struct WORK_SPACE_LIST *next;
} UAEP_WORK_SPACE_LIST;
#endif
typedef struct WORK_SPACE_LIST {
    IRO_WORK_SPACE_ID      wsId;
    WINDOW                 win;
    CHAR                   *wsName;
    struct WORK_SPACE_LIST *next;
} UAEP_WORK_SPACE_LIST;
/*
 * UAEP_SYSTEM_INFO_STRUCT: User Application Event Processing System
 *      Information Structure, maintains information about current IR
 *      session.
 */
typedef struct {
    IR_USER_ID              userId;     /* Users Identifier. */
    IR_LANG_CONFIGURATION   lang;       /* Users Prefered language */
    IR_USER_PRIV_TYPE       priv;       /* Users Privledge in the system. */
    IR_COMM_CONFIGURATION   mode;       /* Polled or interupt driven
					 * system mode. */
    IRO_WORK_SPACE_ID       activeWs;   /* Last Workspace to do anything. */
    UAEP_WORK_SPACE_LIST    *wsRoot;    /* Root of the workspace list. */
} UAEP_SYSTEM_INFO_STRUCT;

typedef SHORT UAEP_DISP_STATUS;

#define UA_POLL_TIME        500         /* Poll every 500 ms. */
#define UA_ONE_MINUTE       60000       /* 1000 * 1ms = 1 sec * 60 = 1 minute */

/*
 * UAEP_DISPLAY_REC: User Application Event Processing Display Record
 *      maintains infomation about a specific record.
 */
typedef struct {
	UAEP_DISP_STATUS        status; /* Status of the record. */
	UARDC_DISPLAY_STRUCT    *d;     /* Actual record to display. */
} UAEP_DISPLAY_REC;

typedef struct {
	SHORT   rec;
	SHORT   line;
} UAEP_REC_LOC;

/*
 * UAEP_WINDOW: User Application Event Processing Window
 *      structure maintains the information associated with the
 *      record display window.
 */
#if 0
typedef struct {
	SHORT magic;              /* magic number to test validity DOC struct */
	CHAR *title;              /* Window Title */
	IRO_WORK_SPACE_ID         wsId;
	IR_ASSOC_ID               assocId;
	SHORT nlines;             /* number of text lines viewable in WS */
	SHORT nRec;               /* number of records kept in the workspace. */
	UAEP_DISPLAY_REC *recs;   /* array of pointers to Display Records. */
	SHORT maxlines;   /* max capacity of lines array */
	SHORT line_height;        /* height of line in pixels */
	SHORT maxwidth;   /* width of longest line (pixels) */
	UAEP_REC_LOC topRec;      /* first visible record on screen */
	SHORT topline;            /* first visible line on screen */
	SHORT horg;               /* horizontal origin (for scrolling) */
	FONT font;                /* font for this window */
	SHORT win_menu_time;      /* counter for menu changes */
	UARDC_RECORD_FORMAT_STRUCT fmt; /* Format for records. */
	PRINT_RCD *p_rcd;         /* print record for this file */
}UAEP_WINDOW;
#endif

typedef struct {
	SHORT magic;              /* magic number to test validity DOC struct */
	CHAR *title;              /* Window Title */
	IRO_WORK_SPACE_ID         wsId;
	SHORT nlines;             /* number of text lines viewable in WS */
	SHORT nRec;               /* number of records kept in the workspace. */
	UAEP_DISPLAY_REC *recs;   /* array of pointers to Display Records. */
	SHORT maxlines;   /* max capacity of lines array */
	SHORT line_height;        /* height of line in pixels */
	SHORT maxwidth;   /* width of longest line (pixels) */
	UAEP_REC_LOC topRec;      /* first visible record on screen */
	SHORT topline;            /* first visible line on screen */
	SHORT horg;               /* horizontal origin (for scrolling) */
	FONT font;                /* font for this window */
	SHORT win_menu_time;      /* counter for menu changes */
	UARDC_RECORD_FORMAT_STRUCT fmt; /* Format for records. */
	PRINT_RCD *p_rcd;         /* print record for this file */
}UAEP_WINDOW;

/*
 * UAEP_DIALOG: User Application Event Processing Dialog union is a
 * union of all structure required for the various dialog boxes.
 */
typedef struct{
	BOOLEAN         cancelled;      /* Did the usr Cancel? */
	EP_DIALOG_UNION data;           /* Data for each dialog */
}UAEP_DIALOG;

/***************************************************
 * Search Control CSC Data Structures.
 ***************************************************/

/*
 * UASC_COMM_EVENT_DATA_TYPE: User Application Search Control Commnunication
 *      Event Data Type explaines the type of communication event data
 *      which is being passed into the Search Communication Handler.
 */
typedef IR_COMM_EVENT_STATUS    UASC_COMM_EVENT_DATA_TYPE;

/* The defines for this type follows */
#define UASC_SEARCH_COMPLETE    IR_COMM_DATA_SEARCH_SRVC


/*
 * UASC_MAINT_TYPE: User Application Search Control Maintenance type.
 */
typedef short UASC_MAINT_TYPE;

/* The defines for this type follows */
#define UASC_MAINT_LOAD_FILE            1       /* Load query file */
#define UASC_MAINT_SAVE_FILE            2       /* Save query file */
#define UASC_MAINT_STORE_ACT_QRY        3       /* Store active query */
#define UASC_MAINT_STORE_ACT_DB         4       /* Store active database */
#define UASC_MAINT_GET_FILE             5       /* Get query file */
#define UASC_MAINT_GET_ACT              6       /* Get active search */
#define UASC_MAINT_CLEAR_FILE           7       /* Clear query file */
#define UASC_MAINT_CLEAR_ACT            8       /* Clear active search */

typedef struct
{
	IR_ASSOC_ID             assocId;
	LONG                    smallSetUpperBound;     /* -1 for default */
	LONG                    largeSetPresentNum;     /* -1 for default */
	LONG                    mediumSetPresentNum;    /* -1 for default */
	BOOLEAN                 replaceIndicator;       /* if supported */
	VISIBLE_STRING          resultSetName;          /* optional - default */
	IR_LIST                 dbNameList;             /* Database list */
	IR_ELEM_SET_NAME_TYPE   smallSetNameType;
	IR_ELEM_SET_NAMES       smallSetNames;
	IR_ELEM_SET_NAME_TYPE   mediumSetNameType;
	IR_ELEM_SET_NAMES       mediumSetNames;
	OBJECT_IDENTIFIER       recordSyntax;
} UASC_DATABASE_INFO;

/*
 * UASC_SEARCH_TYPE: is used to contain all the information involved
 * in a Search.
 */
typedef struct {
	RPN_Structure       *query;     /* RPN Query Information. */
	UASC_DATABASE_INFO  database;   /* Database information. */
} UASC_SEARCH_TYPE;

/*
 * UASC_MAINT_REQ: User Application Search Control Maintenance Request
 *      structure maintains information required to perform a search
 *      maintenance request.
 */
typedef union {
	UA_FILENAME         fileName;   /* File name to get. */
	UASC_SEARCH_TYPE    search;     /* Search info to add. */
}UASC_MAINT_REQ;

typedef struct {
    BOOLEAN             canSearch;
    UASC_SEARCH_TYPE    search;
}UASC_ACT_STRUCT;

/*
 * UASC_MAINT_REP: User Application Search Control Maintenance Reply
 *      structure maintains the  information returned from a search
 *      maintenance request.
 */
typedef union {
	UASC_ACT_STRUCT     act;    /* Reply to active search request.*/
	SHORT               numberSearchs;
	UASC_SEARCH_TYPE    *searchs;
	BOOLEAN             canSearch;
}UASC_MAINT_REPLY;

/* 
 * UASC_SEARCH_FILE: User Application Search Control Search File
 *      structure maintains all the information associated with the
 *      internal list of query requests.
 */
typedef struct {
	int placeHolder;
}UASC_SEARCH_FILE;

/* 
 * UASC_ACTIVE_SEARCH: User Application Search Control Active Search 
 *      structure maintains all the information associated with the
 *      current search attempt.
 */
typedef struct {
	int placeHolder;
} UASC_ACTIVE_SEARCH;

/***************************************************
 * Association Control CSC Data Structures.
 ***************************************************/

/*
 * UAAC_COMM_EVENT_DATA_TYPE: User Application Association Control
 *      Communication Event Data Type explaines the type of communication 
 *      event data which is being passed into the Association Communication 
 *      Handler.
 */
typedef IR_COMM_EVENT_STATUS    UAAC_COMM_EVENT_DATA_TYPE;

#define UAAC_ASSOC_CONNECT      IR_COMM_DATA_CONNECT
#define UAAC_INIT_COMPLETE      IR_COMM_DATA_INIT_SRVC
#define UAAC_ASSOC_ABORT        IR_COMM_DATA_ABORT
#define UAAC_ASSOC_RELEASE      IR_COMM_DATA_RELEASE

/*
 * UAAC_ASSOC_INFO_TYPE: User Application Association Control
 *      Information Type indcates the action to be perfromed during
 *      association maintenance.
 */
typedef short UAAC_ASSOC_INFO_TYPE;

#define UAAC_GET_ALL_ASSOCS     0
#define UAAC_GET_ONE_ASSOC      (UAAC_GET_ALL_ASSOCS + 1)
#define UAAC_GET_IDLE_ASSOC     (UAAC_GET_ALL_ASSOCS + 2)
#define UAAC_GET_INIT_ASSOC     (UAAC_GET_ALL_ASSOCS + 3)
#define UAAC_GET_SEARCH_ASSOC   (UAAC_GET_ALL_ASSOCS + 4)
#define UAAC_GET_PRESENT_ASSOC  (UAAC_GET_ALL_ASSOCS + 5)
#define UAAC_GET_DELETE_ASSOC   (UAAC_GET_ALL_ASSOCS + 6)
#define UAAC_GET_RSRC_RPT_ASSOC (UAAC_GET_ALL_ASSOCS + 7)

/***************************************************
 * Record Display and Control CSC Data Structures.
 ***************************************************/

/*
 * UARDC_COMMAND_TYPE: User Application Record Display Control command
 *      type determines the operation to be performed during a record
 *      maintenance command.
 */
typedef short UARDC_COMMAND_TYPE;

/*
 * UARDC_DISPLAY_RECORD: User Application Record Display Control
 *      contains an unformatted record.
 */
typedef struct {
	int placeHolder;
}UARDC_DISPLAY_RECORD;

/*
 * UARDC_FORMAT_RECORD: User Application Record Display Control 
 *      contains a formatted record.
 */
typedef struct {
	int placeHolder;
}UARDC_FORMAT_RECORD;

/***************************************************
 * Presentation Control CSC Data Structures.
 ***************************************************/

/*
 * UAPC_COMMAND_ID: User Application Presentation Control Command 
 *      Identifier determines the action to be performed during 
 *      presentation maintenance.
 */
typedef short UAPC_COMMAND_ID;

#define         UAPC_FETCH_RECORDS      1 /* Fetch records from a target */
#define         UAPC_DELETE_SET         2 /* Delete a result set on a target */

/*
 * UAPC_REQ_DATA: User Application Presentation Control Request
 *      Data maintains the input data to a presentation management
 *      request.
 */
typedef union {
	IRO_PRESENT_REQ pReq;
	IRO_DELETE_REQ  dReq;
}UAPC_REQ_DATA;

/*
 * UAPC_COMM_EVENT_DATA_TYPE: User Application Presentation Control
 *      Communication Event Data Type explaines the type of communication 
 *      event data which is being passed into the Presentation Communication 
 *      Handler.
 */
typedef IR_COMM_EVENT_STATUS    UAPC_COMM_EVENT_DATA_TYPE;

#define UAPC_RESULT_DELETED     IR_COMM_DATA_DELETE_SRVC
#define UAPC_PRESENT_COMPLETE   IR_COMM_DATA_PRESENT_SRVC

/***************************************************
 * Access and Resource Control CSC Data Structures.
 ***************************************************/

/*
 * UAARC_COMMAND_ID: User Application Access and Resource Control
 *      Command Identifier indicates the operation to be performed
 *      by resource and access control maintence.
 */
typedef short UAARC_COMMAND_ID;

/*
 * UAARC_REQUEST:User Application Access and Resource Control
 *      Request structure maintains the input to resource and
 *      access control maintenance.
 */
typedef struct {
	int placeHolder;
}UAARC_REQUEST;

/*
 * UAARC_COMM_EVENT_DATA:User Application Access and Resource Control
 *      Communication Event Data Type explaines the type of communication 
 *      event data which is being passed into the Access and Resource
 *      Communication Handler.
 */
typedef IR_COMM_EVENT_STATUS    UAARC_COMM_EVENT_DATA_TYPE;

#define UAARC_ACCESS_CNTRL      IR_COMM_DATA_ACCS_SRVC
#define UAARC_RESOURCE_CNTRL    IR_COMM_DATA_RSRC_CNTL_SRVC
#define UAARC_RESOURCE_REPORT   IR_COMM_DATA_RSRC_RPT_SRVC

/***************************************************
 * User Access Control CSC Data Structures.
 ***************************************************/

/*
 * UAUAC_COMMAND_ID: User Application User Access Control Command
 *      Identifier indicates the action to be taken for User Information
 *      maintenance.
 */
typedef short UAUAC_COMMAND_ID;

/*
 * UAUAC_USER_REQ: User Application User Access Control User Request
 *      maintains the input for User Information maintenance.
 */
typedef struct {
	int placeHolder;
}UAUAC_USER_REQ;

/*
 * UAUAC_USER_REP: User Application User Access Control User Reply
 *      maintains the output for User Information maintenance.
 */
typedef struct {
	int placeHolder;
}UAUAC_USER_REP;

/*
 * UASC_DB_INFO_STRUCT: used by the user application to maintain database
 * and target information about a single target.
 */
typedef struct {
	IR_ASSOC_ID             assocId;
	IR_USER_TARGET_INFO     userTgInfo;
	IR_TARGET_INFO          tgInfo;
	BOOLEAN                 isMalloced;
} UASC_DB_INFO_STRUCT;

/**************************************************************************
 * FUNCTION Definitions.
 *
 **************************************************************************/

#ifdef XVT_MSDOS
/* User Application Event Processing Function Definitions. */
IR_STATUS UaEp_Init(void);
void UaEp_DeleteAssocId(IR_ASSOC_ID);
void UaEp_Menu(WINDOW, MENU_TAG, BOOLEAN, BOOLEAN);
void UaEp_MenuSetStatus(MENU_TAG, BOOLEAN);
BOOLEAN UaEp_MenuGetStatus(MENU_TAG);
void UaEp_MenuState(void);
IR_STATUS UaEp_Dialog(UAEP_DIALOG_TYPE, UAEP_DIALOG *);
void UaEp_MouseDouble(WINDOW, RCT, PNT);

/*  User Application System information maintanence. */
IR_USER_ID UaEp_InfoUserId(void);
CHAR *UaEp_NewWorkspace(IRO_WORK_SPACE_ID);
IR_STATUS UaEp_UpdateWin(IRO_WORK_SPACE_ID wsId);
IRO_WORK_SPACE_ID UaEp_GetActiveWs(void);
CHAR *UaEp_GetWsName(IRO_WORK_SPACE_ID wsId);
void UaEp_DeleteRecList(UAEP_DISPLAY_REC *recList, SHORT nRecs);
void UaEp_DelWorkspace(IRO_WORK_SPACE_ID);
CHAR *UaEp_GenerateName(IRO_WORK_SPACE_ID wsId);

IR_USER_ID      UaEp_UserInfoId(void);

/* User Application Association Control Function Definitions. */
IR_STATUS UaAc_AbortAssociation(IR_ASSOC_ID);
void UaAc_MakeAssociation(UAEP_DIALOG *dlgRqst);
void UaAc_BreakAssociation(UAEP_DIALOG *dlgRqst);
IR_STATUS UaAc_CommEvent(UAAC_COMM_EVENT_DATA_TYPE, IRO_COMM_EVENT_REPLY*);
IR_STATUS UaAc_GetAssociationInfo(UAAC_ASSOC_INFO_TYPE, IR_ASSOC_ID, IR_LIST *);
IR_STATUS UaAc_GetAssociationInfoFull(IR_ASSOC_ID, IRO_ASSOC_FULL_INFO_STRUCT *);
void      UaAc_UpdateStatus(void);
void      UaAc_DestroyFullInfoStruct(IRO_ASSOC_FULL_INFO_STRUCT *);
void    UaAc_CommStatusUpdate(void);
void UaAc_ResetTimer(IR_ASSOC_ID);
void UaAc_SetTimerDuration(SHORT);
void UaAc_CheckTimeout(void);
void UaAc_RemoveTimedItem(IR_ASSOC_ID);
SHORT UaAc_GetTimerDuration(void);

/* User Application Search Control Function Definitions. */
IR_STATUS UaSc_GetDatabase(void);
IR_STATUS UaSc_ClearSearch(void);
IR_STATUS UaSc_BuildQuery(void);
IR_STATUS UaSc_SendSearch(void);
UA_STATUS UaSc_Maintenance(UASC_MAINT_TYPE, UASC_MAINT_REQ *, UASC_MAINT_REPLY  *);
IR_STATUS UaSc_CommEvent(UASC_COMM_EVENT_DATA_TYPE, IRO_COMM_EVENT_REPLY *);
/* UASC Utilities */
void UaSc_CopyDB(UASC_DATABASE_INFO *from, UASC_DATABASE_INFO *to);
void UaSc_ClearDB(UASC_DATABASE_INFO *db);
void UaSc_DbDestroyDbInfoStruct(CHAR *, void *);
void UaSc_DbFillTargetInfo(IR_TARGET_ID, UASC_DB_INFO_STRUCT *);
void UaSc_DbInitDbInfoStruct(UASC_DB_INFO_STRUCT *);
UASC_DB_INFO_STRUCT *UaSc_DbCreateDbInfoStruct(CHAR *src);
void UaSc_QExprUpDown(WINDOW, int);
void UaSc_DbHandleTargetList(WINDOW, SLIST, SLIST *);
IR_STATUS UaSc_DbInitDlg(WINDOW, SLIST, SLIST **);
void UaSc_DbDestroyDlg(WINDOW, SLIST*);
void UaSc_DbGetDatabases(WINDOW, UAEP_DIALOG *, SLIST, SLIST*);
void UaSc_DbOptionsButton(WINDOW, UAEP_DIALOG *);
void UaSc_DispSyntaxList(IR_LIST *, SLIST); /* list of IR_DATABASE_INFO */
void UaSc_DispElemSetList(IR_LIST *, SLIST); /* list of IR_DATABASE_INFO */
void UaSc_GetSyntaxFromList(WINDOW, SLIST, OBJECT_IDENTIFIER *); /* returns null term oid */
void UaSc_GetElemSetNameFromList(WINDOW, SLIST, VISIBLE_STRING *);
void UaSc_DoDlgInit(WINDOW);
void UaSc_DoDlgDestroy(WINDOW);
void UaSc_DoDlgOK(WINDOW, UAEP_DIALOG *);
void UaSc_DestroyQueryHist(void);
IR_STATUS UaSc_GetHistoryList(SLIST);
void UaSc_SelectHistQuery(SHORT);
int UaSc_DestroyHistQuery(SHORT);


/* User Application Presentation Control Function Definitions. */
void UaPc_ResultShow(void);
IR_STATUS UaPc_FetchResult(void);
IR_STATUS UaPc_DeleteResult(void);
IR_STATUS UaPc_CommEvent(UAPC_COMM_EVENT_DATA_TYPE, IRO_COMM_EVENT_REPLY *);
IR_STATUS UaRdc_CommEvent(UAPC_COMM_EVENT_DATA_TYPE, IRO_COMM_EVENT_REPLY *);
IR_STATUS UaPc_Manage(UAPC_COMMAND_ID, UAPC_REQ_DATA *);

/* User Application Record Display Control Function Definitions. */
IR_STATUS UaRdc_DisplayResult(void);
IR_STATUS UaRdc_Format(UARDC_RECORD_FORMAT_STRUCT *, UARDC_RECORD_STRUCT *, UARDC_DISPLAY_STRUCT * );
IR_STATUS UaRdc_DRDlgInit(WINDOW, SLIST);
void UaRdc_DRDlgDestroy(WINDOW);
void UaRdc_DRDlgGetSelect(WINDOW, SLIST, UAEP_DIALOG *);
void UaRdc_DRDlgHandleList(WINDOW, SLIST, UAEP_DIALOG *);
IR_STATUS UaRdc_DelRemDlgOk(WINDOW, UAEP_DIALOG *);

/* User Application Access and Resource Control Function Definitions. */
IR_STATUS UaArc_CommEvent(UAARC_COMM_EVENT_DATA_TYPE, IRO_COMM_EVENT_REPLY *);
IR_STATUS UaArc_CreateList(SLIST, UAEP_DIALOG *);
SHORT UaArc_AccessControlReq(WINDOW, UAEP_DIALOG *);
SHORT UaArc_AccessControlResp(WINDOW, UAEP_DIALOG *);
SHORT UaArc_CreateInfoDlg(WINDOW, UAEP_DIALOG *);

IR_STATUS       UaCs_Init(void);
void            UaCs_Terminate(void);
void            UaCs_DeleteAssocId(IR_ASSOC_ID assocId);
IR_ASSOC_ID     UaCs_GetNewAssocId(void);

void            UaHec_Message(CHAR *, CHAR *, BOOLEAN);
void            UaHec_Initialize();
void            UaHec_UserMsg(CHAR *source, UAHEC_MSG_TYPE msgType, 
		    UAHEC_MSG_ID msgId, CHAR *strData, USHORT iData);
void            UaHec_ReportUAErorr(CHAR *src, CHAR *str);
void            UaHec_ReportIROError(CHAR *src, IRO_FUNC_NAME func, 
		    IRO_FUNC_REC_TYPE recType);
IR_STATUS       UaHec_AddAssocName(IR_ASSOC_ID assocId, VISIBLE_STRING *name);
IR_STATUS       UaHec_UpdateAssocName(IR_ASSOC_ID assocId,VISIBLE_STRING *name);
VISIBLE_STRING  *UaHec_GetAssocName(IR_ASSOC_ID assocId);
void            UaHec_DeleteAssocName(IR_ASSOC_ID assocId);
void            UaHec_InitAssocNameTbl(void);
void            UaHec_ToggleDispMsg(SHORT, BOOLEAN);
void UaEp_CalcDimensions(WINDOW);
void UaEp_ScrollSync(WINDOW);
void UaEp_DeleteWs(UAEP_WINDOW *);
void UaEp_DoUpdate(WINDOW, RCT);
void UaEp_DoScroll(WINDOW, SCROLL_TYPE, SCROLL_CONTROL, short);
BOOLEAN UaEp_PrintDocument(WINDOW win);
void UaEp_SetTopRec(UAEP_WINDOW *info);
void UaEp_NextRec(UAEP_REC_LOC *rec, UAEP_WINDOW *info);
void UaEp_GetPrinterSize(PRINT_RCD *pr, long *height, long *width);
UAEP_WINDOW *UaEp_NewDoc(long data);
WINDOW UaEp_InvokeWSWin(long data);
UAEP_WINDOW *UaEp_GetWinInfo(WINDOW win);
IR_STATUS       UaEp_SaveWinData(IRO_WORK_SPACE_ID wsId, char *filename);

#else
IR_STATUS UaEp_Init(void);
void UaEp_DeleteAssocId(IR_ASSOC_ID);

/*  User Application System information maintanence. */
IR_USER_ID UaEp_InfoUserId(void);
CHAR *UaEp_NewWorkspace(IRO_WORK_SPACE_ID);
IR_STATUS UaEp_UpdateWin(IRO_WORK_SPACE_ID wsId);
IRO_WORK_SPACE_ID UaEp_GetActiveWs(void);
CHAR *UaEp_GetWsName(IRO_WORK_SPACE_ID wsId);
void UaEp_DeleteRecList(UAEP_DISPLAY_REC *recList, SHORT nRecs);
void UaEp_DelWorkspace(IRO_WORK_SPACE_ID);
CHAR *UaEp_GenerateName(IRO_WORK_SPACE_ID wsId);

/* User Application Association Control Function Definitions. */
IR_STATUS UaAc_AbortAssociation(IR_ASSOC_ID);
void UaAc_MakeAssociation(UAEP_DIALOG *dlgRqst);
void UaAc_BreakAssociation(UAEP_DIALOG *dlgRqst);
IR_STATUS UaAc_CommEvent(UAAC_COMM_EVENT_DATA_TYPE, IRO_COMM_EVENT_REPLY*);
IR_STATUS UaAc_GetAssociationInfo(UAAC_ASSOC_INFO_TYPE, IR_ASSOC_ID, IR_LIST *);
IR_STATUS UaAc_GetAssociationInfoFull(IR_ASSOC_ID, IRO_ASSOC_FULL_INFO_STRUCT *);
void      UaAc_UpdateStatus(void);
void      UaAc_DestroyFullInfoStruct(IRO_ASSOC_FULL_INFO_STRUCT *);
void    UaAc_CommStatusUpdate(void);
void UaAc_ResetTimer(IR_ASSOC_ID);
void UaAc_SetTimerDuration(SHORT);
void UaAc_CheckTimeout(void);
void UaAc_RemoveTimedItem(IR_ASSOC_ID);
SHORT UaAc_GetTimerDuration(void);

/* User Application Search Control Function Definitions. */
IR_STATUS UaSc_GetDatabase(void);
IR_STATUS UaSc_ClearSearch(void);
IR_STATUS UaSc_BuildQuery(void);
IR_STATUS UaSc_SendSearch(void);
UA_STATUS UaSc_Maintenance(UASC_MAINT_TYPE, UASC_MAINT_REQ *, UASC_MAINT_REPLY  *);
IR_STATUS UaSc_CommEvent(UASC_COMM_EVENT_DATA_TYPE, IRO_COMM_EVENT_REPLY *);
/* UASC Utilities */
void UaSc_CopyDB(UASC_DATABASE_INFO *from, UASC_DATABASE_INFO *to);
void UaSc_ClearDB(UASC_DATABASE_INFO *db);
void UaSc_DbDestroyDbInfoStruct(CHAR *, void *);
void UaSc_DbFillTargetInfo(IR_TARGET_ID, UASC_DB_INFO_STRUCT *);
void UaSc_DbInitDbInfoStruct(UASC_DB_INFO_STRUCT *);
UASC_DB_INFO_STRUCT *UaSc_DbCreateDbInfoStruct(CHAR *src);
void UaSc_DestroyQueryHist(void);
void UaSc_SelectHistQuery(SHORT);
int UaSc_DestroyHistQuery(SHORT);


/* User Application Presentation Control Function Definitions. */
void UaPc_ResultShow(void);
IR_STATUS UaPc_FetchResult(void);
IR_STATUS UaPc_DeleteResult(void);
IR_STATUS UaPc_CommEvent(UAPC_COMM_EVENT_DATA_TYPE, IRO_COMM_EVENT_REPLY *);
IR_STATUS UaPc_Manage(UAPC_COMMAND_ID, UAPC_REQ_DATA *);

/* User Application Record Display Control Function Definitions. */
IR_STATUS UaRdc_DisplayResult(void);
IR_STATUS UaRdc_Format(UARDC_RECORD_FORMAT_STRUCT *, UARDC_RECORD_STRUCT *, UARDC_DISPLAY_STRUCT * );

/* User Application Access and Resource Control Function Definitions. */
IR_STATUS UaArc_CommEvent(UAARC_COMM_EVENT_DATA_TYPE, IRO_COMM_EVENT_REPLY *);

IR_STATUS       UaCs_Init(void);
void            UaCs_Terminate(void);
void            UaCs_DeleteAssocId(IR_ASSOC_ID assocId);
IR_ASSOC_ID     UaCs_GetNewAssocId(void);

void            UaHec_Message(CHAR *, CHAR *, BOOLEAN);
void            UaHec_Initialize();
void            UaHec_UserMsg(CHAR *source, UAHEC_MSG_TYPE msgType, 
		    UAHEC_MSG_ID msgId, CHAR *strData, USHORT iData);
void            UaHec_ReportUAErorr(CHAR *src, CHAR *str);
void            UaHec_ReportIROError(CHAR *src, IRO_FUNC_NAME func, 
		    IRO_FUNC_REC_TYPE recType);
IR_STATUS       UaHec_AddAssocName(IR_ASSOC_ID assocId, VISIBLE_STRING *name);
IR_STATUS       UaHec_UpdateAssocName(IR_ASSOC_ID assocId,VISIBLE_STRING *name);
VISIBLE_STRING  *UaHec_GetAssocName(IR_ASSOC_ID assocId);
void            UaHec_DeleteAssocName(IR_ASSOC_ID assocId);
void            UaHec_InitAssocNameTbl(void);
void            UaHec_ToggleDispMsg(SHORT, BOOLEAN);

#endif
#endif
