
/************************************************************************
 *
 * SR/Z3950 application software version 1.0, August 1993.
 *
 * (C) Software Kinetics Ltd.
 *
 * Software Kinetics Ltd. has granted a licence of this software to the
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve, reproduce
 * and sell the software.
 *
 * The software is provided to the user "as is" without warranty of any
 * kind. Neither Software Kinetics Ltd. nor the National Library of Canada
 * warrants, guarantees or makes any representations regarding the use,
 * or the results of use of the software in terms of accuracy, reliability,
 * or otherwise. The entire risk as to results and performance of the
 * software is assumed by the user. Neither Software Kinetics Ltd. nor the
 * National Library of Canada shall be liable for any direct, indirect,
 * consequential or incidental damages arising out of the use of the
 * software.
 *
 ************************************************************************/

/****************************************************************************
 * HEADER dialog.h
 *
 * PURPOSE:
 *	This header file is used for dialog specific information.
 *
 * SCOPE:
 *	Any User Application Event Processing CSC which interact with dialog 
 *	should include this header file to ensure that the correct system wide 
 *	types are being used.
 *	
 * NOTES:
 *	Character pointers specified in any structure element are null 
 *	terminated ASCII strings unless a count is associated with it.
 *
 *
 * $Log:
 * Revision 1.1  1993/09/16  09:03:27  irorigin
 * Baseline for Release 1.0.
 *
 * 
 ****************************************************************************/

#ifndef DIALOG_H

#define DIALOG_H
#include<ir.h>
#include <ir_api.h>
#include<ua.h>
#ifdef XVT_MSDOS
#include<xvt.h>
#endif
#include<ua/rpnquery.h>

/****************************************************************************
 * DIALOG Common Constants and Types:
 ****************************************************************************/

#define EP_DLG_EDIT_SZ		120	/* Size of text input string */


typedef char		EP_DLG_EDIT_TYPE[EP_DLG_EDIT_SZ + 1];
typedef char		*EP_DLG_VIRT_EDIT_TYPE;


typedef SHORT DLG_CONNECT_TYPE; /* Menu catagory item selected by. */
#define FILE_CONNECT_TYPE	0	/* Item selected from File menu */
#define EDIT_CONNECT_TYPE	1	/* Item selected from Edit menu */
#define CONN_CONNECT_TYPE	2	/* Item selected from connection menu */
#define SRCH_CONNECT_TYPE	3	/* Item selected from search menu. */
#define RSLT_CONNECT_TYPE	4	/* Item selected from the result menu */
#define OPTN_CONNECT_TYPE	5	/* Item selected from the options menu */


/*
 * Displayable characters
 */

#define ARC_IDLE      '*'
#define ARC_INIT      'I'
#define ARC_SEARCH    'S'
#define ARC_PRESENT   'F'
#define ARC_DELETE    'D'
#define ARC_RSRC_RPRT 'R'
#define ARC_UNKNOWN   '?'
#define ARC_CONNECT   'C'
#define ARC_ABORTING  'A'

/*
 * Access and Resource Control Push button selections.
 */
#define ARC_RESOURCE_REPORT	1
#define ARC_TRIG_RESOURCE_CTRL	2
#define ARC_ABORT_ASSOC		3
#define ARC_STOP_OPERATION	4
#define ARC_ASSOC_INFORMATION	5

/*
 * Get Assoc Character based on Assoc State
 */
#define GET_ASSOC_CHAR(state) \
	((state == IRO_ASSOC_STATE_IDLE) ? (ARC_IDLE):\
	(state == IRO_ASSOC_STATE_INIT) ? (ARC_INIT):\
	(state == IRO_ASSOC_STATE_CONNECT) ? (ARC_CONNECT):\
	(state == IRO_ASSOC_STATE_SEARCH) ? (ARC_SEARCH):\
	(state == IRO_ASSOC_STATE_PRESENT) ? (ARC_PRESENT):\
	(state == IRO_ASSOC_STATE_DELETE) ? (ARC_DELETE):\
	(state == IRO_ASSOC_STATE_ABORTING) ? (ARC_ABORTING):\
	(state == IRO_ASSOC_STATE_RSRC_RPRT) ? (ARC_RSRC_RPRT): (ARC_UNKNOWN))



typedef struct {
	RPN_Structure	*tree;	/* The tree structure for the current query */
	int 			current_item_num;

	/* These variables contain the state of the current term */
	RPN_AttribComplete	at_completeness;
	RPN_AttribPosition	at_position;
	RPN_AttribRelation	at_relation;
	RPN_AttribStruct	at_structure;
	RPN_AttribTrunc		at_truncation;
	RPN_AttribUse		at_use;

	RPN_Operator		operator;	/* -1 if `none' is selected */
	BOOLEAN 		search; 	/* User wishes to attempt a search */
	EP_DLG_EDIT_TYPE	value;		/* value field */
	RPN_ATTRIB_CLASS	class;
	CHAR			*className;
	int			classIndex;
	BOOLEAN			isMalloced;
} EP_DLG_QUERY_SEARCH_STRUCT;

typedef struct {
	IR_ASSOC_ID		assocId;
	LONG			smallSetUpperBound;	/* -1 for default */
	LONG			largeSetPresentNum;	/* -1 for default */
	LONG			mediumSetPresentNum;	/* -1 for default */
	BOOLEAN			replaceIndicator;	/* if supported */
	VISIBLE_STRING		resultSetName;		/* optional - default */
	IR_LIST			dbNameList;		/* Database list */
	IR_ELEM_SET_NAME_TYPE	smallSetNameType;
	IR_ELEM_SET_NAMES	smallSetList;
	IR_ELEM_SET_NAME_TYPE	mediumSetNameType;
	IR_ELEM_SET_NAMES	mediumSetList;
	OBJECT_IDENTIFIER 	recordSyntax;
	BOOLEAN			search;	/* Search Option has been selected. */
	BOOLEAN			isMalloced;
} EP_DLG_DATABASE_SEARCH_STRUCT;

/*
 * EP_DLG_NEW_CONNECT_STRUCT: Event Processing New Connection Dialog
 * Information Structure.
 */
typedef struct {
	EP_DLG_EDIT_TYPE 	name;		/* Connection name */
	EP_DLG_EDIT_TYPE	address;	/* IP address or host name */
	EP_DLG_EDIT_TYPE	userId;		/* User Id if required. */
	EP_DLG_EDIT_TYPE	acctId;		/* Account Id if required. */
	EP_DLG_EDIT_TYPE	password;	/* Password if required. */
	BOOLEAN			isMalloced;
} EP_DLG_NEW_CONNECT_STRUCT;

/* 
 * EP_DLG_MAKE_CONNECT_STRUCT: Event Processing Make Connection Dialog
 * Information Structure.
 */
typedef struct {
	IR_TARGET_ID		targetId;	/* Target Identifier */
	IR_STATUS		irStatus;	/* Status of New Assoc call*/
	BOOLEAN			isMalloced;
} EP_DLG_MAKE_CONNECT_STRUCT;

/* 
 * EP_DLG_BRAKE_CONNECT_STRUCT: Event Processing Brake Connection Dialog
 * Information Structure.
 */
typedef struct {
	EP_DLG_EDIT_TYPE 	name;		/* Connection name */
	IR_ASSOC_ID		assocId;	/* Association Identifier */
	BOOLEAN 		abort;		/* Must we abort? */
	IR_TARGET_ID		targetId;	/* Target Identifier */
	BOOLEAN			isMalloced;
} EP_DLG_BRAKE_CONNECT_STRUCT;

/*
 * EP_DLG_LOGIN_STRUCT: Event Processing Login Dialog information Structure.
 */
typedef struct {
	EP_DLG_EDIT_TYPE      name;	/* User Name */
	EP_DLG_EDIT_TYPE      password;	/* Users password. */
	IR_USER_ID	      userId;	/* User Id of user. */
	IR_USER_PRIV_TYPE     privilege;/* User Privledge. */
	IR_LANG_CONFIGURATION prefLang; /* User Prefered Language. */
	BOOLEAN			isMalloced;
} EP_DLG_LOGIN_STRUCT;

typedef struct {
	IR_ASSOC_ID	assocId;	/* Association id to fetch from */
	BOOLEAN			isMalloced;
} EP_DLG_FETCH_RESLT_STRUCT;

typedef struct {
	IRO_WORK_SPACE_ID	wsId;	/* Work space id  */
	LONG			numRecOnTarget;
	LONG			nextPosOnTarget;
	LONG			numRecInWs;
	IR_ASSOC_ID		assocId;
	IRO_WS_HEADER_INFO	*wsHdrInfo;
	BOOLEAN			isMalloced;
} EP_DLG_DISPLAY_RESLT_STRUCT;




typedef struct {
	DLG_CONNECT_TYPE      connectType;  /* Input to the dialog. */
	IR_ASSOC_ID	      assocId;	    /* Association id to fetch from */
	SHORT		      buttonSel;    /* Push button selection. */
	BOOLEAN 	      abort;	    /* Abort item. */
	BOOLEAN 	      resrcRptOnly; /* Only do resorce rpt. idle conn*/
	BOOLEAN 	      rsltSetWanted;/* Want result set. */
	BOOLEAN			isMalloced;
} EP_DLG_ARC_STATUS_STRUCT;


typedef struct {
	IR_ASSOC_ID	  assocId;	/* Association request received from */
	EP_DLG_EDIT_TYPE  targetName;	/* Name of target involved. */
	EP_DLG_EDIT_TYPE  targetData;	/* Cntl Info required. */
	EP_DLG_EDIT_TYPE  userReply;	/* Users input. */
	BOOLEAN			isMalloced;
} EP_DLG_ARC_RSRC_CNTL_STRUCT;


typedef struct {
	CHAR	  *title;	/* Title for message */
	CHAR	  *message;	/* Message to display. */
} EP_DLG_SHOW_STRUCT;


/*
 * EP_DIALOG_UNION: A union of all of the dialog specific structures
 * used by the system.
 */
typedef union {
	EP_DLG_MAKE_CONNECT_STRUCT 	makeConnect;
	EP_DLG_NEW_CONNECT_STRUCT 	newConnect;
	EP_DLG_BRAKE_CONNECT_STRUCT	breakConnect;
	EP_DLG_LOGIN_STRUCT		login;
	EP_DLG_QUERY_SEARCH_STRUCT	query;
	EP_DLG_DATABASE_SEARCH_STRUCT	database;
	EP_DLG_FETCH_RESLT_STRUCT	fetch;
	EP_DLG_DISPLAY_RESLT_STRUCT	display;
	EP_DLG_ARC_STATUS_STRUCT	arcStatus;
	EP_DLG_ARC_RSRC_CNTL_STRUCT	rsrcCtl;
	EP_DLG_SHOW_STRUCT		show;
} EP_DIALOG_UNION;

/*
 * DIALOG FUNCTION PROTOTYPES
 */
#ifdef XVT_MSDOS
char *EpDialog_IsInList(SLIST list, long value);
IR_STATUS EpDialog_GetSelListData(WINDOW win, SLIST list, long *data);
IR_STATUS EpDialog_SetSelListData(WINDOW win, SLIST list, long data);
SHORT EpDialog_GetEditShort(WINDOW win);
void EpDialog_HidePasswd(WINDOW cwin, char *passwd);
void EpDialog_NoWhiteSpace(WINDOW cwin, char *buf);
void EpDialog_AlphaOnly(WINDOW cwin);
void EpDialog_IsDigit(WINDOW cwin);
#endif

#endif /* DIALOG_H */
