
/************************************************************************
 *
 * SR/Z3950 application software version 1.0, August 1993.
 *
 * (C) Software Kinetics Ltd.
 *
 * Software Kinetics Ltd. has granted a licence of this software to the
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve, reproduce
 * and sell the software.
 *
 * The software is provided to the user "as is" without warranty of any
 * kind. Neither Software Kinetics Ltd. nor the National Library of Canada
 * warrants, guarantees or makes any representations regarding the use,
 * or the results of use of the software in terms of accuracy, reliability,
 * or otherwise. The entire risk as to results and performance of the
 * software is assumed by the user. Neither Software Kinetics Ltd. nor the
 * National Library of Canada shall be liable for any direct, indirect,
 * consequential or incidental damages arising out of the use of the
 * software.
 *
 ************************************************************************/

/****************************************************************************
 * HEADER ua_param.h
 *
 * PURPOSE:
 *	This header file is the UA include file for parameters to
 *	read in by the main function.
 *
 * SCOPE:
 *	Only UA uaeappl.c CSC may include this header file.
 *	
 * NOTES:
 *	Character pointers specified in any structure element are null 
 *	terminated ASCII strings unless a count is associated with it.
 *
 *
 * $Log:
 * Revision 1.1  1993/09/16  09:03:27  irorigin
 * Baseline for Release 1.0.
 *
 ****************************************************************************/

#ifndef UA_PARAM_H

#define UA_PARAM_H

#include <ir.h>

/*
 * PARAM_ERROR message string
 */
#define PARAM_ERROR "Invalide command line parameter \"IR /L[e|f] /C[p|e]\" default %s/%s driven used"

#define PARAM_LEN	3

/* TYPES of Parameters. */
typedef CHAR		UA_PARAM_TYPE;
#define LANG_PARAM	'L'	/* Language type parameter. */
#define COMM_PARAM	'C'	/* Communciations Parameter. */
#define DEBUG_PARAM	'D'	/* Debug statements into log. */
#define APDU_LOG_PARAM	'A'	/* Debug APDUs into log. */
#define UNKNOWN_PARAM	'\0'	/* Parameter is unknown. */


/* Sub parameter types */
typedef CHAR		UA_PARAM_VALUE;
#define LANG_ENG_PARAM	'E'	/* English lanugage selected. */
#define LANG_FRN_PARAM	'F'	/* French language sellected. */
#define COMM_POLL_PARAM 'P'	/* Polled communication selected. */
#define COMM_EVNT_PARAM 'E'	/* Event driven communications selected.*/
#define TRUE_PARAM	'T'	/* True for debug and debug apdus */
#define FALSE_PARAM	'F'	/* False for debug and debug apdus */

/* Macros */
/*
 * PARAM_START returns a postive value if the character is either a '-'
 * or a '/' indicating the start of a parameter.
 */
#define SLASH_START	'/'
#define DASH_START	'-'
#define PARAM_START(checkChar) ((checkChar == SLASH_START) ? (1) :\
				(checkChar == DASH_START) ? (1): (0))

/*
 * LANG_PARAM_INVALID Returns a postive value if the parameter passed
 * is not a valid language parameter.
 */
#define LANG_PARAM_INVALID(param) ((param == LANG_ENG_PARAM) ? (0):\
				  (param == LANG_FRN_PARAM) ? (0): (1))
/*
 * COMM_PARAM_INVALID Returns a postive value if the parameter passed
 * is not a valid communications parameter.
 */
#define COMM_PARAM_INVALID(param) ((param == COMM_POLL_PARAM) ? (0):\
				  (param == COMM_EVNT_PARAM) ? (0): (1))

/* GET_LANG returns a valid IRO lang value for a valid lang param. */
#define GET_LANG(param) ((param == LANG_ENG_PARAM) ? (IR_ENGLISH):\
						    (IR_FRENCH))

/* GET_COMM returns a valid IRO comm value for a valid comm param. */
#define GET_COMM(param) ((param == COMM_POLL_PARAM) ? \
				  (IR_COMM_CONF_EVENT_POLLED):\
				  (IR_COMM_CONF_EVENT_INT))

/* True or false parameter checking */
#define BOOLEAN_PARAM(param) ((param == TRUE_PARAM) ? TRUE : FALSE)


#define PARAM_ERROR1(lang) ((lang)?"French":"English")

#define PARAM_ERROR2(comm) ((comm)?"Polled":"Event")

#endif /* UA_PARAM_H */
