/****************************************************************************
 * HEADER uaepmsg.h
 *
 * PURPOSE:
 *	This header file contains all message types for ua message
 *	reporting to the user.
 *
 * SCOPE:
 *	This header file is used by any ua unit that wishes to display
 *	a message to the user.
 *	
 * NOTES:
 *
 *
 * $Log:
 * Revision 1.1  1993/09/16  09:03:27  irorigin
 * Baseline for Release 1.0.
 *
 * 
 ****************************************************************************/

#ifndef UAEPMSG_H

#define UAEPMSG_H

/*
 * Message Types.
 */
#define UAEP_MSG_TYPE_AC		1
#define UAEP_MSG_TYPE_EP		2
#define UAEP_MSG_TYPE_SC		3
#define UAEP_MSG_TYPE_ARC		4

/*
 * Message ids
 */
#define MSG_ID_INVALID			(-1)
#define MSG_ID_AC_BASE			0
#define MSG_ID_AC_CONNECTING		(MSG_ID_AC_BASE + 1)
#define MSG_ID_AC_CONNECTED		(MSG_ID_AC_BASE + 2)
#define MSG_ID_AC_CONN_REFUSED		(MSG_ID_AC_BASE + 3)
#define MSG_ID_AC_UNKNOWN_HOST		(MSG_ID_AC_BASE + 4)
#define MSG_ID_AC_INIT_COMPLETE		(MSG_ID_AC_BASE + 5)
#define MSG_ID_AC_INIT_FAIL		(MSG_ID_AC_BASE + 6)
#define MSG_ID_AC_CONN_REL		(MSG_ID_AC_BASE + 7)
#define MSG_ID_AC_CONN_REL_FAIL		(MSG_ID_AC_BASE + 8)
#define MSG_ID_AC_ABORT			(MSG_ID_AC_BASE + 9)
#define MSG_ID_AC_ABORT_FAIL		(MSG_ID_AC_BASE + 10)
#define MSG_ID_AC_PROTOCOL_ERROR	(MSG_ID_AC_BASE + 11)
#define MSG_ID_AC_TIMEOUT		(MSG_ID_AC_BASE + 12)

#define MSG_ID_EP_BASE			100
#define MSG_ID_EP_LOGIN_REQD		(MSG_ID_EP_BASE + 1)
	

#define NO_STRING	""

typedef SHORT		UAHEC_MSG_ID;
typedef SHORT		UAHEC_MSG_TYPE;


/*
 * Bib1 diagnostic error codes.
 */
#define BIB1_DIAG_PSE		1
#define BIB1_DIAG_TSE		2
#define BIB1_DIAG_US		3
#define BIB1_DIAG_TOESW		4
#define BIB1_DIAG_TMAW		5
#define BIB1_DIAG_TMBO		6
#define BIB1_DIAG_TMTW		7
#define BIB1_DIAG_TMIS		8
#define BIB1_DIAG_TWTS		9
#define BIB1_DIAG_IFFRNST	10
#define BIB1_DIAG_TMCISS	11
#define BIB1_DIAG_TMRR		12
#define BIB1_DIAG_PROOR		13
#define BIB1_DIAG_SEIPR		14
#define BIB1_DIAG_RNATBSI	15
#define BIB1_DIAG_REPMS		16
#define BIB1_DIAG_REMRS		17
#define BIB1_DIAG_RSNSAAST	18
#define BIB1_DIAG_OSRSASTMS	19
#define BIB1_DIAG_OAOASRSASTS	20
#define BIB1_DIAG_RSEARIO	21
#define BIB1_DIAG_RSNNS		22
#define BIB1_DIAG_COSDNS	23
#define BIB1_DIAG_ESNNS		24
#define BIB1_DIAG_SESNNVFSD	25
#define BIB1_DIAG_OASESNS	26
#define BIB1_DIAG_RSNLEUDBT	27
#define BIB1_DIAG_RSIIU		28
#define BIB1_DIAG_OOTSDIL	29
#define BIB1_DIAG_SRSDNE	30
#define BIB1_DIAG_RENRA		31
#define BIB1_DIAG_REUPRA	32
#define BIB1_DIAG_REVSORA	33
#define BIB1_DIAG_100_UE		100
#define BIB1_DIAG_100_ACF		101
#define BIB1_DIAG_100_SCRBCNBIRT	102
#define BIB1_DIAG_100_SCRBCNBIRNI	103
#define BIB1_DIAG_100_SCFRNI		104
#define BIB1_DIAG_100_TBNCR		105
#define BIB1_DIAG_100_NASATFTR		106
#define BIB1_DIAG_100_QTNS		107
#define BIB1_DIAG_100_MQ		108
#define BIB1_DIAG_100_DU		109
#define BIB1_DIAG_100_OU		110
#define BIB1_DIAG_100_TMDS		111
#define BIB1_DIAG_100_TMRSC		112
#define BIB1_DIAG_100_UAT		113
#define BIB1_DIAG_100_UUA		114
#define BIB1_DIAG_100_UVFUA		115
#define BIB1_DIAG_100_UARBNS		116
#define BIB1_DIAG_100_URA		117
#define BIB1_DIAG_100_USA		118
#define BIB1_DIAG_100_UPA		119
#define BIB1_DIAG_100_UTA		120
#define BIB1_DIAG_100_UAS		121
#define BIB1_DIAG_100_UCA		122
#define BIB1_DIAG_100_UAC		123
#define BIB1_DIAG_100_UCVFT		124
#define BIB1_DIAG_100_MST		125
#define BIB1_DIAG_100_ITVFA		126
#define BIB1_DIAG_100_UFFUNV		127
#define BIB1_DIAG_100_IRSN		128
#define BIB1_DIAG_100_PSOSNS		129
#define BIB1_DIAG_100_IRSIPS		130
#define BIB1_DIAG_100_UPR		131
#define BIB1_DIAG_100_UPUC		132

/*
 * Search result set status.
 */
#define Z3950_RSS_SUBSET		1
#define Z3950_RSS_INTERIM		2
#define Z3950_RSS_NONE			3

/*
 * Search and Present present status
 */
#define Z3950_PS_SUCCESS		0
#define Z3950_PS_PARTIAL_1		1
#define Z3950_PS_PARTIAL_2		2
#define Z3950_PS_PARTIAL_3		3
#define Z3950_PS_PARTIAL_4		4
#define Z3950_PS_FAILURE		5


/*
 * Delete status.
 */
#define Z3950_DS_SUCCESS		0
#define Z3950_DS_RSDNE			1
#define Z3950_DS_PDBYT			2
#define Z3950_DS_SPAT			3
#define Z3950_DS_ANA			4
#define Z3950_DS_RCAO			5
#define Z3950_DS_RCAT			6
#define Z3950_DS_BDNS			7
#define Z3950_DS_NARSDOBD		8
#define Z3950_DS_NARRSD			9

/*
 * Resource Control Partial Results.
 */
#define Z3950_RCPR_SUBSET		1
#define Z3950_RCPR_INTERIM		2
#define Z3950_RCPR_NONE			3

/*
 * Resource Report Status.
 */
#define Z3950_RRS_SUCCESS		0
#define Z3950_RRS_PARTIAL		1
#define Z3950_RRS_FAILURE_1		2
#define Z3950_RRS_FAILURE_2		3
#define Z3950_RRS_FAILURE_3		4
#define Z3950_RRS_FAILURE_4		5


#define MSG_DIAG_TYPE_BIB1		1
#define MSG_DIAG_TYPE_RSS		2
#define MSG_DIAG_TYPE_PS		3
#define MSG_DIAG_TYPE_DS		4
#define MSG_DIAG_TYPE_RCPR		5
#define MSG_DIAG_TYPE_RRS		6


void UaHec_GetDiagMsg(SHORT diagType, SHORT diagCode, CHAR **msg);
#endif
