
/************************************************************************
 *
 * SR/Z3950 application software version 1.0, August 1993.
 *
 * (C) Software Kinetics Ltd.
 *
 * Software Kinetics Ltd. has granted a licence of this software to the
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve, reproduce
 * and sell the software.
 *
 * The software is provided to the user "as is" without warranty of any
 * kind. Neither Software Kinetics Ltd. nor the National Library of Canada
 * warrants, guarantees or makes any representations regarding the use,
 * or the results of use of the software in terms of accuracy, reliability,
 * or otherwise. The entire risk as to results and performance of the
 * software is assumed by the user. Neither Software Kinetics Ltd. nor the
 * National Library of Canada shall be liable for any direct, indirect,
 * consequential or incidental damages arising out of the use of the
 * software.
 *
 ************************************************************************/

/****************************************************************************
 * HEADER usmarc.h
 *
 * PURPOSE:
 *	This header file is the general UA include file.  
 *
 * SCOPE:
 *	All UA CSCs must include this header file to ensure that the
 *	correct system wide types are being used.
 *	
 * NOTES:
 *	Character pointers specified in any structure element are null 
 *	terminated ASCII strings unless a count is associated with it.
 *
 *
 * $Log:
 * Revision 1.1  1993/09/16  09:03:27  irorigin
 * Baseline for Release 1.0.
 *
 * 
 ****************************************************************************/

#ifndef USMARC_H

#define USMARC_H
#include <ir.h>


/****************************************************************************
 * USMARC Common Constants and Types:
 ****************************************************************************/

#define USMARC_FIELD_TERM	(CHAR)0x1E /* End of field indicator */
#define USMARC_REC_TERM		(CHAR)0x1D /* End of record indicator */
#define USMARC_SUB_FIELD	(CHAR)0x1F /* Sub-field indicator */
#define USMARC_SF_REPLACEMENT	" $%c "    /* Replacement string for a
					    * Sub field indicator. */
#define USMARC_DIR_START	24	   /* Offset to start of directory */
#define USMARC_BASE_OFFSET	12	   /* Offset into leader for base 
					    * data address */
#define USMARC_BASE_SIZE	5	   /* Num. chars. in base offset */

/*
 * String size indicators.
 */
#define USMARC_TAG_SIZE 	3	/* size of a tag */
#define USMARC_LEN_SIZE 	4	/* size of a field length field */
#define USMARC_OFFSET_SIZE 	5	/* size of the offset to the field */
#define USMARC_BUF_SIZE 	10000	/* largest field for in a reply */
#define USMARC_INDICATOR_SIZE	2	/* Size of variable field indicator
					 * Marks. */

/* Invalid USMARC tag. */
#define USMARC_INVALID_TAG	""
#define USMARC_SPACE		' '
#define USMARC_SF_SIZE		4
#define USMARC_FXTLEN_008	"008"
#define USMARC_FXTLEN_007	"007"
/*
 * USMARC_TAG: User Application Record Display Control USMARC 
 * Tag is a string to maintain a USMARK tag.
 */
typedef CHAR	USMARC_TAG[USMARC_TAG_SIZE];
typedef CHAR	USMARC_LENGTH[USMARC_LEN_SIZE];
typedef CHAR	USMARC_OFFSET[USMARC_OFFSET_SIZE];

#define	NEXT_FIELD	1
#define	PREV_FIELD	2
#define	FIRST_FIELD	3
#define	CURRENT_FIELD	4

typedef struct {
	char	marc[USMARC_BASE_SIZE];
	char 	*field;
} USMARC_FIELD_DATA;


/*
 * USMARC_RECORD: User Application Record Display Control USMARC
 * Record contains a USMARC formatted record.
 */
typedef CHAR *USMARC_RECORD;

/*
 * USMARC_DIR_ENTRY:
 */
typedef struct {
	USMARC_TAG 		tag;
	USMARC_LENGTH		length;
	USMARC_OFFSET 		offset;
} USMARC_DIR_ENTRY;
	

#endif /* USMARC_H */
